@@ -21,7 +21,7 @@
  (define (EditLilyPond)
     (define current (d-DirectiveGet-standalone-postfix tag))
     (if tag
-        (let ((text (d-GetUserInput (_ "Modifying the LilyPond Text") (_ "Give LilyPond to be issued") current)))
+        (let ((text (d-GetUserInput (_ "Modifying the LilyPond Text") (_ "Give LilyPond syntax to be emitted by this Denemo Directive") current)))
             (if text
                 (begin (d-DirectivePut-standalone-postfix tag text) 
                         (d-SetSaved #f))
@@ -58,7 +58,6 @@
     (if (pair? tag)
         (begin (set! dis (cdr tag)) (set! tag (car tag)))
         (set! dis tag))
-    (d-SetSaved #f)
     ((eval-string proc-put) tag content)
     (if (member DENEMO_OVERRIDE_GRAPHIC overrides) ; If DENEMO_OVERRIDE_GRAPHIC is there just go on
         ((eval-string proc-ovr) tag (apply logior overrides))
@@ -66,6 +65,7 @@
             ((eval-string proc-ovr) tag (apply logior (append (list DENEMO_OVERRIDE_GRAPHIC) overrides)))
             ((eval-string proc-ovr) tag (apply logior overrides)))) ; not a staff, everythings ok without DENEMO_OVERRIDE_GRAPHIC
     ((eval-string proc-dis) tag dis)
+    (d-SetSaved #f)
     #t)
 
 (define (EditStaffDirective tag)        
@@ -96,9 +96,26 @@
         (begin  ((eval-string proc-del) tag)
                 (d-SetSaved #f)
                 #f)
-    (apply AttachDirective type field (cons tag dis) content overrides)))
-      
+        (apply AttachDirective type field (cons tag dis) content overrides)))
 
+;;;;;;provides the editing options for a standalone directive that can only be toggled off/on.      
+(define (EditForStandaloneToggle tag)
+    (let ((choice (RadioBoxMenu 
+         (cons (_ "Help") 'help)
+         (cons (_ "Edit Similar") 'similar) 
+         (cons (_ "Object Inspector") 'inspect) 
+         (cons (_ "Delete") 'delete))))
+            (case choice
+                ((similar) (d-EditSimilar))
+                ((help) (let ((thehelp (d-GetHelp tag)))
+                                (if (string? thehelp)
+                                    (d-InfoDialog thehelp #f)
+                                    (d-InfoDialog (_ "No help!")))))
+                ((inspect)
+                   (d-DisplayCurrentObject))
+                  ((delete)
+                    (d-DirectiveDelete-standalone tag)))))
+                      
 ; d-DirectivePut-standalone a convenience function for standalone directives
 (define (d-DirectivePut-standalone tag)
   (d-DirectivePut-standalone-minpixels tag 0)
@@ -125,6 +142,37 @@
       (d-DirectivePut-score tag))
 
 
+;;procedure for creating/updating a directive attached to the the score expects the parameters a test for the directive already present a procedure for putting the directive one for deleting it a tag then two fields for getting a new value a default value a proc for testing the validity of the value and information to give the user when the directive is deleted.
+(define (ManageSystemDirective  params present? put-proc get-proc del-proc tag title prompt  value test  deletion-info)
+    (if (number? params)
+        (begin
+            (put-proc (number->string params)))
+        (begin
+            (if (present? tag)
+                (let ((choice (RadioBoxMenu (cons (_ "Help") 'help) (cons (_ "Edit") 'edit) (cons (_ "Delete") 'delete))))
+                    (case choice
+                        ((help)
+                            (let ((thehelp (d-GetHelp tag)))
+                                (set! params 'cancel)
+                                (if (string? thehelp)
+                                    (d-InfoDialog thehelp #f)
+                                    (d-InfoDialog (_ "No help!")))))
+                        ((delete)
+                            (d-SetSaved #f)
+                            (del-proc tag)
+                            (set! params 'cancel)
+                            (d-InfoDialog deletion-info #f)) ;#f => modal
+                        ((edit)
+                            (set! params (get-proc))
+                            (if (test params)
+                                (begin
+                                    (set! value params)
+                                    (set! params #f))
+                                (set! params 'cancel))))))
+                     (if (not (eq? params 'cancel))
+                (let ((value (d-GetUserInput title prompt value)))
+                    (if (test value)
+                        (put-proc value)))))))
 
   
 
@@ -245,7 +293,7 @@
     (if (d-Directive-chord? tag)
           (d-DirectiveDelete-chord tag)
           (begin
-            (d-SetSaved #f)
+           
             (if fontname
                 (begin
                     (d-DirectivePut-chord-gx tag 7)
@@ -254,18 +302,34 @@
                 (d-DirectivePut-chord-display tag display))
             (d-DirectivePut-chord-postfix tag lilypond)
             (if override
-          (d-DirectivePut-chord-override tag override)))))
+          (d-DirectivePut-chord-override tag override))
+           (d-SetSaved #f))))
 
-(define (SetDirectiveConditional)
-(define choice #f)
-(set! choice (RadioBoxMenu
-                     (cons (string-append (_ "Only for the Layout for Part \"") (d-StaffProperties "query=lily_name") "\"")   'only)   
-                        (cons (string-append (_ "Only for Layout \"") (d-GetLayoutName) "\"") 'default)
-                        (cons (_ "For all Layouts") 'all)))
-                (case choice
-                    ((all) (d-ForAllLayouts))
-                    ((default) (d-OnlyForLayout (cons (d-GetLayoutName) (d-GetLayoutId))))
-                    ((only) (d-OnlyForLayout   (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId))))))
+(define* (SetDirectiveConditional #:optional (directive #f))
+    (define choice (if (equal? (d-StaffProperties "query=lily_name") (d-GetLayoutName))
+                        (RadioBoxMenu
+                            (cons (string-append (_ "Only for Layout \"") (d-GetLayoutName) "\"") 'default)
+                            (cons (string-append (_ "Ignore for Layout \"") (d-GetLayoutName) "\"") 'ignore-default)
+                            (cons (_ "For all Layouts") 'all))
+                        (RadioBoxMenu
+                            (cons (string-append (_ "Only for the Layout for Part \"") (d-StaffProperties "query=lily_name") "\"")   'only)   
+                            (cons (string-append (_ "Ignore for the Layout for Part \"") (d-StaffProperties "query=lily_name") "\"")   'ignore-only)   
+                            (cons (string-append (_ "Only for Layout \"") (d-GetLayoutName) "\"") 'default)
+                            (cons (string-append (_ "Ignore for Layout \"") (d-GetLayoutName) "\"") 'ignore-default)
+                            (cons (_ "For all Layouts") 'all))))
+    (if (pair? directive)
+        (case choice
+            ((ignore-only) (d-DirectiveNotForLayout (cons (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId)) directive))) 
+            ((ignore-default)  (d-DirectiveNotForLayout (cons (cons (d-GetLayoutName) (d-GetLayoutId))directive)))
+            ((all) (d-DirectiveForAllLayouts directive))
+            ((default) (d-DirectiveOnlyForLayout (cons (cons (d-GetLayoutName) (d-GetLayoutId)) directive)))
+            ((only) (d-DirectiveOnlyForLayout  (cons (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId)) directive))))
+        (case choice
+            ((ignore-only) (d-NotForLayout (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId))))
+            ((ignore-default) (d-NotForLayout (cons (d-GetLayoutName) (d-GetLayoutId))))
+            ((all) (d-ForAllLayouts))
+            ((default) (d-OnlyForLayout (cons (d-GetLayoutName) (d-GetLayoutId))))
+            ((only) (d-OnlyForLayout (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId)))))))
 
 ;;; Toggle the DENEMO_OVERRIDE_HIDDEN override of the directive at the cursor
 (define (ToggleHidden type tag) ;;; eg (ToggleHidden "note" "Fingering")
