@@ -62,9 +62,8 @@
         (set! oldy "0"))
     (set! offsetx (number->string (+ (string->number offsetx) (string->number oldx))))
     (set! offsety (number->string (+ (string->number offsety) (string->number oldy))))
-
-    (d-DirectivePut-standalone-prefix tag (string-append "<>-\\tweak #'extra-offset #'(" offsetx " . " offsety ")")) 
-    (if (list? data)
+    (d-DirectivePut-standalone-prefix tag (string-append " <>-\\tweak #'extra-offset #'(" offsetx " . " offsety ")"))
+    (if (pair? data)
         (begin
             (set! data (assq-set! data 'x-offset offsetx))
             (set! data (assq-set! data 'y-offset offsety))
@@ -503,9 +502,10 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                                     (set! menu (cons  (cons "Set Font Size"  alter-font-size)  menu))
                                     (set! menu (cons  (cons "Alter Text"  alter-text)  menu))))
                          
+                          (set! menu (cons (cons (_ "Object Editor") d-EditCursorObject) menu))
+                          (set! menu (cons (cons (_ "Object Inspector") d-DisplayCurrentObject) menu))
                          
-                         
-                         (set! choice (d-PopupMenu menu))
+                          (set! choice (d-PopupMenu menu))
                           (if choice
                                 (choice)
                                 (disp "cancelled")))))
@@ -516,7 +516,10 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                                 ;;; FIXME the value is relative to the centre line of the staff, this gets relative to the tr sign.
                                 ;;;need to use d-GetNewTarget to find the notehead position, then use its mid_c_offset to get the centre line value
                                 ;;; beaming does this
-                           
+                                                   
+                                (set! menu (cons (cons (_ "Object Editor") d-EditCursorObject) menu))
+                                (set! menu (cons (cons (_ "Object Inspector") d-DisplayCurrentObject) menu))
+
                                 
                                 (set! choice (d-PopupMenu menu))
                                 (if choice
@@ -583,15 +586,17 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                                             (if (d-Directive-chord? "Tie")                                      
                                                 (set! menu (cons (cons RestoreTiePrompt 
                                                                                                     remove-tie-shaping) menu )))))                                                             
-                                                                                                    
+                                                             
+                                    (set! menu (cons (cons (_ "Object Editor") d-EditCursorObject) menu))
+                                    (set! menu (cons (cons (_ "Object Inspector") d-DisplayCurrentObject) menu))
+                                                                
                                     (set! choice (d-PopupMenu menu))
                                     (if choice
                                         (choice)
                                         (disp "cancelled"))))))))))  ;EditTarget end        
                                             
 ;;;; Toggles a postfix annotation on a chord, with editing for direction or offset
-(define* (ChordAnnotation tag lilypond params graphic #:optional display)
-  (define current-direction "^")
+(define* (ChordAnnotation tag lilypond params graphic #:optional display (current-direction "^"))
     (define (set-option option)
           (if (not (or (equal? current-direction "^") (equal? current-direction "-") (equal? current-direction "_")))
             (set! current-direction "-"))
@@ -608,7 +613,7 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                     (set! choice (cond  ((equal? choice (_ "Up")) "^")
                                                             ((equal? choice (_ "Down")) "_")
                                                             ((equal? choice (_ "Auto")) "-")))
-                    (d-DirectivePut-chord-postfix tag (string-append  (string-append choice " " lilypond " ")))
+                    (d-DirectivePut-chord-postfix tag (string-append  (string-append (if (and (AtRest?) (d-GetNonprinting)) "<>" "") choice " " lilypond " ")))
                     (d-SetSaved #f)))))
     (if (and (d-Directive-chord? tag) (equal? params "edit"))
         (case (GetEditOption)
@@ -622,11 +627,15 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                     (if (and (d-Directive-chord? tag) (list? params))
                                     (begin
                                         (d-SetSaved #f)
-                                        (set! current-direction (substring (string-trim (d-DirectiveGet-chord-postfix tag)) 0 1))
-                                        (d-DirectivePut-chord-postfix tag (string-append  (string-join (map-in-order set-option params))  lilypond " ")))
+                                         (if (and (AtRest?) (d-GetNonprinting))
+                                            (set! current-direction (substring (string-trim (d-DirectiveGet-chord-postfix tag)) 0 1))
+                                            (set! current-direction (substring (string-trim (d-DirectiveGet-chord-postfix tag)) 3 4))) ;;;FIXME use scheme data field to store this, <>- etc
+                                            
+                                            
+                                        (d-DirectivePut-chord-postfix tag (string-append (if (and (AtRest?) (d-GetNonprinting)) "<>" "") (string-join (map-in-order set-option params))  lilypond " ")))
                                     (d-WarningDialog "Cannot complete operation - cursor moved or bad parameter list")))
             (begin  ;;;no parameters, toggle annotation off/on
-                    (ToggleChordDirective tag graphic (string-append "-" lilypond) DENEMO_OVERRIDE_ABOVE display)))))
+                    (ToggleChordDirective tag graphic (string-append  (if (and (AtRest?) (d-GetNonprinting)) "<>" "")  "-" lilypond) DENEMO_OVERRIDE_ABOVE display)))))
                                             
 (define* (ChordOrnament tag lilypond params graphic #:optional display)
        (ChordAnnotation tag lilypond params graphic display))  
