@@ -168,8 +168,8 @@
                     (set! offsety (d-GetUserInput (_ "Offset Position") (_ "Amount (+/-) to nudge in vertical direction") offsetx))
                     (if offsety
                         (cons offsetx offsety)
-                        #f)
-                #f))))
+                        #f))
+                #f)))
 
 ;;;;;;;;;;;;;;;; Double-Stroke for sequencing keypresses. By Nils Gey June 2010
 ;One parameter for the GUI-version or help window. This is the version that appears if someone clicks on the menu version.
@@ -228,8 +228,8 @@
 ;;;;;;;;;; SetHeaderField sets a field in the movement header
 ;;;;;;;;;; the directive created is tagged Score or Movement depending on the field
 
-(define* (SetHeaderField field #:optional (title #f) (escape #t) (movement #f))
-  (let ((current "") (thematch #f) (tag "") (type "") (fieldname ""))
+(define* (SetHeaderField field #:optional (title #f) (escape #t) (movement #f)(extra-space "0")(bold #f)(italic #f)(fontsize #f))
+  (let ((current "") (thematch #f) (tag "") (type "") (fieldname "")(data #f))
     (if (or (equal? field "subtitle") (equal? field "subsubtitle") (equal? field "piece"))
      (begin
        (set! type "Movement")
@@ -245,7 +245,19 @@
      (if movement
         (set! type "Movement"))
     (set! tag (string-append type fieldname)) 
+    
+    
     (set! current (d-DirectiveGet-header-data tag))
+    ;;;old versions have a string, new versions an alist beginning 'right paren ie ' 0x28 in Unicode 50 octal.
+    (if (and current (> (string-length current)) (eq? (string-ref current 0) #\') (eq? (string-ref current 1) #\50))
+        (begin
+            (set! data (eval-string current))
+            (set! extra-space (assq-ref data 'extra-space))
+            (set! bold (assq-ref data 'bold))
+            (set! fontsize (assq-ref data 'fontsize))
+            (set! current (assq-ref data 'title)))
+        (set! data '()))
+    
     (if (not current)
         (set! current (d-DirectiveGet-header-display tag)))
     (if (not current)
@@ -253,33 +265,85 @@
                     
     (if (not title)
             (set! title (d-GetUserInput (string-append type " " fieldname)
-                    (string-append "Give a name for the " fieldname " of the " type) current #f)))
+                    (string-append "Give a name for the " fieldname " of the " type) current #t)))
+  (if (and title fontsize)
+    (begin
+       (set! bold (RadioBoxMenu (cons (_ "Bold") " ") (cons (_ "Normal") " \\normal-text ")))
+       (if (not bold) (set! bold ""))
+       (set! italic (RadioBoxMenu  (cons (_ "Upright") "") (cons (_ "Italic") " \\italic ")))
+       (if (not italic) (set! italic ""))
+       (set! extra-space (d-GetUserInput (string-append "Score " field) 
+                        (_ "Extra space above (0):") extra-space #t))
+       (if not extra-space (set! extra-space "0"))
+
+       (set! fontsize (d-GetUserInput (_ "Font Magnification") (_ "Give font magnification required (+/-) 0 ") fontsize))
+       (if (not fontsize)
+            (set! fontsize "0")))
+    (begin
+        (set! bold "")
+        (set! italic "")
+        (set! fontsize "0")))
+              
     (if title
       (begin
                 (d-SetSaved #f)
                 (if (string-null? title)
                     (d-DirectiveDelete-header tag)
                     (let ((movement (number->string (d-GetMovement))))
+                        (set! data (assq-set! data 'title title))
+                        (set! data (assq-set! data 'bold bold))
+                        (set! data (assq-set! data 'italic italic))
+                        (set! data (assq-set! data 'fontsize fontsize))
+                        (set! data (assq-set! data 'extra-space extra-space))
                         (if escape (set! title (scheme-escape title )))
-                            (d-DirectivePut-header-override tag (logior DENEMO_OVERRIDE_TAGEDIT DENEMO_OVERRIDE_GRAPHIC))
-                            (d-DirectivePut-header-data tag title)
-                            
-                            (d-DirectivePut-header-display tag (DenemoAbbreviatedString title))
-                            (d-DirectivePut-header-postfix tag (string-append field " = \\markup { \\with-url #'\"scheme:(d-GoToPosition " movement " 1 1 1)(d-" type fieldname ")\" "  "\"" title "\"}\n")))))
-            (disp "Cancelled\n"))))
+                        (d-DirectivePut-header-override tag (logior DENEMO_OVERRIDE_TAGEDIT DENEMO_OVERRIDE_GRAPHIC))
+                        (d-DirectivePut-header-data tag (format #f "'~s" data))
+                        
+                        (d-DirectivePut-header-display tag (DenemoAbbreviatedString title))
+                        (d-DirectivePut-header-postfix tag (string-append field " = \\markup {\\vspace #'" extra-space " \\fontsize #'" fontsize italic bold  " \\with-url #'\"scheme:(d-GoToPosition " movement " 1 1 1)(d-" type fieldname ")\" "  "\"" title "\"}\n")))))
+        (disp "Cancelled\n"))))
 
 ; SetScoreHeaderField sets a field in the score header
-(define* (SetScoreHeaderField field  #:optional (title #f) (escape #t) (full-title #f))
-(let ((current "") (tag ""))
+(define* (SetScoreHeaderField field  #:optional (title #f) (escape #t) (full-title #f) (extra-space "0")(bold #f)(italic #f)(fontsize #f))
+(let ((current "") (tag "")(data #f))
   (set! tag (string-append "Score" (string-capitalize field)))
   (set! current (d-DirectiveGet-scoreheader-data tag))
+      ;;;old versions have a string, new versions an alist beginning 'right paren ie ' 0x28 in Unicode 50 octal.
+  (if (and current (> (string-length current)) (eq? (string-ref current 0) #\') (eq? (string-ref current 1) #\50))
+        (begin
+            (set! data (eval-string current))
+            (set! extra-space (assq-ref data 'extra-space))
+            (set! bold (assq-ref data 'bold))
+            (set! fontsize (assq-ref data 'fontsize))
+            (set! current (assq-ref data 'title)))
+        (set! data '()))
+        
   (if (not current)
         (set! current (d-DirectiveGet-scoreheader-display tag)))
   (if (not current)
       (set! current ""))
   (if (not title)
       (set! title  (d-GetUserInput (string-append "Score " field) 
-                  (_ "Give a name applying to the whole score") current #f)))
+                  (_ "Give a name applying to the whole score") current #t)))
+ 
+    ;;;if we have a pre-existing title ask about details, if the user hasn't cancelled the title
+  (if (and title fontsize)
+    (begin
+       (set! bold (RadioBoxMenu (cons (_ "Bold") " ") (cons (_ "Normal") " \\normal-text ")))
+       (if (not bold) (set! bold ""))
+       (set! italic (RadioBoxMenu(cons (_ "Upright") "") (cons (_ "Italic") " \\italic ")))
+       (if (not italic) (set! italic ""))
+       (set! extra-space (d-GetUserInput (string-append "Score " field) 
+                        (_ "Extra space above (0):") extra-space #t))
+       (if not extra-space (set! extra-space "0"))
+       (set! fontsize (d-GetUserInput (_ "Font Magnification") (_ "Give font magnification required (+/-) 0 ") fontsize))
+       (if (not fontsize)
+            (set! fontsize "0")))
+    (begin
+        (set! bold "")
+        (set! italic "")
+        (set! fontsize "0")))
+     
   (if title
     (begin
       (d-SetSaved #f)      
@@ -287,11 +351,17 @@
             (if (string-null? title)
                     (d-DirectivePut-scoreheader-override tag 0)
                     (begin
+                            (set! data (assq-set! data 'title title))
+                            (set! data (assq-set! data 'bold bold))
+                            (set! data (assq-set! data 'italic italic))
+                            (set! data (assq-set! data 'fontsize fontsize))
+                            (set! data (assq-set! data 'extra-space extra-space))
+
                             (d-DirectivePut-scoreheader-override tag (logior DENEMO_OVERRIDE_TAGEDIT DENEMO_OVERRIDE_GRAPHIC))
-                            (d-DirectivePut-scoreheader-data tag title)
+                            (d-DirectivePut-scoreheader-data tag (format #f "'~s" data))
                             (d-DirectivePut-scoreheader-display tag (DenemoAbbreviatedString title))))
             (if (not full-title)
-                (set! full-title (string-append " \\markup { \\with-url #'\"scheme:(d-" tag ")\"  "  "\"" title "\"}\n")))
+                (set! full-title (string-append " \\markup {\\vspace #'" extra-space " \\fontsize #'" fontsize italic bold " \\with-url #'\"scheme:(d-" tag ")\"  "  "\"" title "\"}\n")))
             (d-DirectivePut-scoreheader-postfix tag (string-append field " = " full-title "\n"))))))
 
 (define (CreateButton tag label)
@@ -376,21 +446,32 @@
 (define (DenemoSetPlaybackStart)
   (begin
     (d-Stop)
-    (if (boolean? (d-GetMidiOnTime))
-    (d-RecreateTimebase))
-    (if (number? (d-GetMidiOnTime))
-    (begin (d-SetPlaybackInterval (d-GetMidiOnTime) #t)
-    (d-RefreshDisplay)))))
+    (if (not (d-GetMidiOnTime))
+        (d-RecreateTimebase))
+    (while (and (not (Music?))
+                (d-NextChord)))
+    (if (d-GetMidiOnTime)
+        (begin
+            (d-SetPlaybackInterval (d-GetMidiOnTime) #t)
+            (d-RefreshDisplay)))))
 
 (define (DenemoSetPlaybackEnd)
-  (begin
+  (let ((time #f))
     (d-Stop)
-    (if (boolean? (d-GetMidiOffTime))
-    (d-RecreateTimebase))
-   (d-PrevObject)
-    (if (number? (d-GetMidiOffTime))
-    (begin (d-SetPlaybackInterval #t (d-GetMidiOffTime))
-    (d-RefreshDisplay)))))
+    (if (not (d-GetMidiOffTime))
+        (d-RecreateTimebase))
+    (d-PushPosition)
+    (if (not (Appending?))
+        (d-PrevChord))
+    (if (not (Music?))
+        (d-NextChord))
+    (set! time (d-GetMidiOffTime))
+    (if (and time (> time 0))
+        (begin
+            (d-SetPlaybackInterval #t time)
+            (d-RefreshDisplay)))
+    (d-PopPosition)
+    time))
     
 (define (DenemoSetPlaybackIntervalToSelection)
   (begin
@@ -451,7 +532,8 @@
     (staffloop)))
   (d-PopPosition)
   offtime)
-  
+;;;
+(define d-GetOnsetTime d-GetMidiOnTime)  ;;;was a duplicate, not used by Denemo
 ; DenemoConvert
 (define (DenemoConvert)
 (define MidiNoteStarts (make-vector 256 #f))
@@ -552,16 +634,21 @@
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;
-
-(define (DenemoPrintAllHeaders)
-    (d-LilyPondInclude (cons 'query "book-titling.ily"))
+(define (DenemoHasBookTitles)
+ (d-LilyPondInclude (cons 'query "book-titling.ily"))
     (if (not LilyPondInclude::return)
         (d-LilyPondInclude (cons 'query "simplified-book-titling.ily")))
-  (if LilyPondInclude::return
+  LilyPondInclude::return)
+(define (DenemoUseBookTitles)
+         (d-LilyPondInclude "simplified-book-titling.ily"))
+(define (DenemoHideBookTitles)
+    (d-LilyPondInclude (cons 'delete "book-titling.ily"))
+    (d-LilyPondInclude (cons 'delete "simplified-book-titling.ily")))
+(define (DenemoPrintAllHeaders)
+  (if (DenemoHasBookTitles)
     (begin
       (d-WarningDialog (_ "You had book titles for this score. These are being dropped. To re-instate them, re-set the title as a book title."))
-      (d-LilyPondInclude (cons 'delete "book-titling.ily"))
-      (d-LilyPondInclude (cons 'delete "simplified-book-titling.ily"))))
+      (DenemoHideBookTitles)))
   (d-DirectivePut-paper-postfix "PrintAllHeaders" "\nprint-all-headers = ##t\n"))
      
 (define* (SetQuarterCommaMeanTone #:optional (thestep 0))
@@ -640,8 +727,8 @@
         )
       (else #f)))
 
-(define Pitchbend::commandUp "(d-CursorRight)")
-(define Pitchbend::commandDown "(d-CursorLeft)")
+(define Pitchbend::commandUp #f)
+(define Pitchbend::commandDown #f)
 (define  Pitchbend::timer 0)
 (define (MIDI-shortcut::pitchbend value)
   ;(format #t "pitch bend value ~a\n" value)
@@ -783,10 +870,22 @@
              answer
              (cdr (list-ref  parameters (list-index (lambda (x) (equal?  answer (car x))) parameters))))
         #f))        
-        
 (define (RadioBoxMenu . parameters)
     (RadioBoxMenuList parameters))
 
+(define (TitledRadioBoxMenuList title parameters)
+   (define answer #f)
+    (define radiostring #f)
+    (if (string? (car parameters))
+        (set! radiostring (string-append (string-join parameters stop) stop))
+        (set! radiostring (string-append (string-join (map (lambda (x) (car x)) parameters) stop) stop)))
+    (set! answer (d-GetOption radiostring title))
+    (if answer
+        (if (string? (car parameters))
+             answer
+             (cdr (list-ref  parameters (list-index (lambda (x) (equal?  answer (car x))) parameters))))
+        #f))   
+
 
 ;Protofunction for all transpose and shift related commands
 ;; Get all notes on cursor position and create a list with new values which then exchanges the current notes on cursor position
@@ -932,7 +1031,7 @@
 
 ;;;;;
 (define* (StandaloneText tag text #:optional (direction "-") (italic "\\italic ") (bold "\\bold "))
-    (set! tag (string-append tag "\n" text))
+    ;;;(set! tag (string-append tag "\n" text)) not needed, and with accented characters can cause illegal chars sent to pango_layout_set_text
     (d-Directive-standalone tag)
     (d-DirectivePut-standalone-prefix tag "<>")
     (d-DirectivePut-standalone-postfix tag (string-append direction "\\markup " italic bold "{\"" (scheme-escape text) "\" }"))
@@ -971,7 +1070,7 @@
 ;;;;;;;;;
 (define (GetDefinitionDirectives)
     (define directives '())
-    (let loop ((count 1))
+    (let loop ((count 0))
         (define good-tag (d-DirectiveGetNthTag-score count))
         (if good-tag 
             (begin
@@ -1025,3 +1124,280 @@
                 (if (string-contains note "es")
                     FLAT
                     NATURAL)))))
+;;;;;;;
+(define (DenemoDefaultBeatStructure beats)
+  (define bs "")
+  (if (zero? (remainder beats 3))
+    (begin
+        (set! beats (number->string (/ beats 3)))
+        (set! bs (string-append beats " " beats " " beats)))
+    (if (zero? (remainder beats 2))
+        (begin
+            (set! beats (number->string (/ beats 2)))
+            (set! bs (string-append beats " " beats)))
+        (set! bs (string-append (number->string (/ (- beats 1) 2)) " " (number->string (- beats (/ (- beats 1) 2)))))))
+    bs)
+
+;;;
+(define (DenemoGetDuration title)
+    (TitledRadioBoxMenuList title
+        (list (cons "𝅝" "1/1")
+        (cons "𝅗𝅥" "1/2")
+        (cons "𝅘𝅥" "1/4")
+        (cons "𝅘𝅥𝅮" "1/8") 
+        (cons "𝅘𝅥𝅯" "1/16")
+        (cons "𝅘𝅥𝅱" "1/32")
+        (cons "𝅘𝅥𝅱" "1/64")
+        (cons "𝅘𝅥𝅱" "1/128"))))
+                            
+;;
+(define (DenemoSetTitles tag param editing)
+    (let ((score (equal? tag "ScoreTitles"))
+        (data #f)
+        (dedication #f)
+        (title #f)
+        (subtitle #f)
+        (subsubtitle #f)
+        (instrument #f)
+        (poet #f)
+        (composer #f)
+        (meter #f)
+        (arranger #f)
+        (tagline #f)
+        (copyright #f)
+        (piece #f)
+        (opus #f))
+        (define (get-field field initial)
+            (if (not initial)
+                (set! initial field))
+            (if editing
+              (let ((response  (d-GetUserInputWithSnippets  (if score (_ "Score Titles")  (_ "Movement Titles")) (string-append (_ "Give ") field) initial)))
+                (if response
+                    (car response)
+                    #f))
+            (d-GetUserInput (if score (_ "Score Titles")  (_ "Movement Titles")) (string-append (_ "Give ") field) initial)))
+        (define (write-titles)
+            (let ((header ""))
+                (define (url type)
+                    (if score
+                            (string-append "\\with-url #'\"scheme:(DenemoSetTitles \\\"" tag "\\\" '" type " #t)\" ")
+                            (string-append "\\with-url #'\"scheme:(d-GoToPosition " (number->string (d-GetMovement)) " 1 1 1)(DenemoSetTitles \\\"" tag "\\\" '" type " #t)\"")))
+            
+                (if dedication
+                                (set! header (string-append header "     dedication = \\markup " (url "dedication") " {" dedication "}\n"))
+                                (set! header (string-append header "     dedication = ##f\n")))
+                (if title
+                                (set! header (string-append header "     title = \\markup " (url "title") " {" title "}\n"))
+                                (set! header (string-append header "     title = ##f\n")))
+                (if subtitle
+                                (set! header (string-append header "     subtitle = \\markup " (url "subtitle") " {" subtitle "}\n"))
+                                (set! header (string-append header "     subtitle = ##f\n")))
+                (if subsubtitle
+                                (set! header (string-append header "     subsubtitle = \\markup " (url "subsubtitle") " {" subsubtitle "}\n"))
+                                (set! header (string-append header "     subsubtitle = ##f\n")))
+                (if instrument
+                                (set! header (string-append header "     instrument = \\markup " (url "instrument") " {" instrument "}\n"))
+                                (set! header (string-append header "     instrument = ##f\n")))
+                (if poet
+                                (set! header (string-append header "     poet = \\markup " (url "poet") " {" poet "}\n"))
+                                (set! header (string-append header "     poet = ##f\n")))
+                (if composer
+                                (set! header (string-append header "     composer = \\markup " (url "composer") " {" composer "}\n"))
+                                (set! header (string-append header "     composer = ##f\n")))
+                (if meter
+                                (set! header (string-append header "     meter = \\markup " (url "meter") " {" meter "}\n"))
+                                (set! header (string-append header "     meter = ##f\n")))
+                (if arranger
+                                (set! header (string-append header "     arranger = \\markup " (url "arranger") " {" arranger "}\n"))
+                                (set! header (string-append header "     arranger = ##f\n")))
+                (if tagline
+                                (set! header (string-append header "     tagline = \\markup " (url "tagline") " {" tagline "}\n"))
+                                (set! header (string-append header "     tagline = ##f\n")))
+                (if copyright
+                                (set! header (string-append header "     copyright = \\markup " (url "copyright") " {" copyright "}\n"))
+                                (set! header (string-append header "     copyright = ##f\n")))
+                (if piece
+                                (set! header (string-append header "     piece = \\markup " (url "piece") " {" piece "}\n"))
+                                (set! header (string-append header "     piece = ##f\n")))
+                (if opus
+                                (set! header (string-append header "     opus = \\markup " (url "opus") " {" opus "}\n"))
+                                (set! header (string-append header "     opus = ##f\n")))
+                (d-SetSaved #f)
+                
+                (DenemoPrintAllHeaders);;; here to disable book titles.
+                (if (not (d-Directive-header? "MovementTitles"))
+                 (d-DirectiveDelete-paper "PrintAllHeaders"))
+             
+                (if score
+                    (begin
+                        (d-DirectivePut-scoreheader-postfix tag header)
+                        (d-DirectivePut-scoreheader-display tag (_ "Score Titles"))
+                        (d-DirectivePut-scoreheader-override tag DENEMO_OVERRIDE_GRAPHIC))
+                    (begin
+                        (d-DirectivePut-header-postfix tag header)
+                        (d-DirectivePut-header-display tag (_ "Movement Titles"))
+                        (d-DirectivePut-header-override tag DENEMO_OVERRIDE_GRAPHIC)))
+                ;;; if setting movement titles but no score titles are set then initialize score titles to #f
+                (if (and (not score) (not (d-Directive-scoreheader? "ScoreTitles")))
+                        (DenemoSetTitles "ScoreTitles" 'initialize #f))))
+                        
+(define (form-pair name title)
+    (string-append "(cons '" name (if (string? title) (string-append " \"" (scheme-escape title) "\"") " #f") ")"))
+;;; procedure starts here
+        (if score
+            (set! data (d-DirectiveGet-scoreheader-data tag))
+            (set! data (d-DirectiveGet-header-data tag)))
+        (if data 
+            (begin
+                (set! data (eval-string data))
+                (set! dedication (assq-ref data 'dedication))
+                (set! title (assq-ref data 'title))
+                (set! subtitle (assq-ref data 'subtitle))
+                (set! subsubtitle (assq-ref data 'subsubtitle))
+                (set! instrument (assq-ref data 'instrument))
+                (set! poet (assq-ref data 'poet))
+                (set! composer (assq-ref data 'composer))
+                (set! meter (assq-ref data 'meter))
+                (set! arranger (assq-ref data 'arranger))
+                (set! tagline (assq-ref data 'tagline))
+                (set! copyright (assq-ref data 'copyright))
+                (set! piece (assq-ref data 'piece))
+                (set! opus (assq-ref data 'opus))))
+        (if (not data)
+            (set! data '()))
+
+        (let ((choice (list 
+                (cons (_ "dedication") 'dedication)
+                (cons (_ "title") 'title)
+                (cons (_ "subtitle") 'subtitle)
+                (cons (_ "subsubtitle") 'subsubtitle)
+                (cons (_ "instrument") 'instrument)
+                (cons (_ "poet") 'poet)
+                (cons (_ "composer") 'composer)
+                (cons (_ "meter") 'meter)
+                (cons (_ "arranger") 'arranger))))
+                
+                
+                
+            (if score
+                (set! choice (append choice (list (cons (_ "tagline") 'tagline) (cons (_ "copyright") 'copyright))))
+                (set! choice (append choice (list (cons (_ "piece") 'piece) (cons (_ "opus") 'opus)))))
+
+           (if (d-Directive-scoreheader? "BookTitle")
+                (begin
+                    (set! param 'abort)
+                    (d-WarningDialog (_ "You have book titles created for this score.\nYou can delete them in the score and movement editor and then use simple titles."))))
+                
+            (if param
+                (set! choice param)
+                (set! choice (RadioBoxMenuList choice)))
+            (if (null? data)
+                (begin
+                    (if (or (d-DirectiveGet-scoreheader-postfix "ScoreTitle")
+                            (d-DirectiveGet-header-postfix "ScoreSubsubtitle")
+                            (d-DirectiveGet-header-postfix "ScoreSubtitle")
+                            (d-DirectiveGet-header-postfix "ScoreArranger")
+                            (d-DirectiveGet-header-postfix "ScoreComposer")
+                            (d-DirectiveGet-header-postfix "ScoreDedication")
+                            (d-DirectiveGet-scoreheader-postfix "ScoreInstrument")
+                            (d-DirectiveGet-header-postfix "ScorePoet")
+                            (d-DirectiveGet-header-postfix "ScorePiece")
+                            (d-DirectiveGet-header-postfix "ScoreOpus")
+                            (d-DirectiveGet-header-postfix "ScoreMeter")
+                            (d-DirectiveGet-header-postfix "ScoreTagline")
+                            (d-DirectiveGet-scoreheader-postfix "ScoreCopyright")
+                            (d-DirectiveGet-header-postfix "MovementTitle")
+                            (d-DirectiveGet-header-postfix "MovementSubtitle")
+                            (d-DirectiveGet-header-postfix "MovementPiece"))
+                        (begin
+                            (set! choice 'abort)
+                            (d-WarningDialog (_ "You have simple titles created by an earlier version of Denemo.\nYou can only edit these with 1.2.4 or earlier versions.\nYou can delete them in the score and movement editor and then re-instate them."))))))
+                
+ 
+            (case choice
+                ((dedication)
+                    (set! choice (get-field (_ "dedication") dedication))
+                    (if choice (set! dedication choice)))
+                ((title)
+                            (if title (set! editing #t))
+                            (set! choice (get-field (_ "title") title))
+                    (if choice (set! title choice)))
+                ((subtitle)
+                            (if subtitle (set! editing #t))
+                            (set! choice (get-field (_ "subtitle") subtitle))
+                    (if choice (set! subtitle choice)))
+                ((subsubtitle)
+                            (if subsubtitle (set! editing #t))
+                            (set! choice (get-field (_ "subsubtitle") subsubtitle))
+                    (if choice (set! subsubtitle choice)))
+                ((instrument)
+                            (if instrument (set! editing #t))                
+                            (set! choice (get-field (_ "instrument") instrument))
+                    (if choice (set! instrument choice)))
+                ((poet)
+                            (if poet (set! editing #t))                
+                            (set! choice (get-field (_ "poet") poet))
+                    (if choice (set! poet choice)))
+                ((composer)
+                            (if composer (set! editing #t))                
+
+                            (set! choice (get-field (_ "composer") composer))
+                    (if choice (set! composer choice)))
+                ((meter)
+                            (if meter (set! editing #t))                
+                            (set! choice (get-field (_ "meter") meter))
+                    (if choice (set! meter choice)))
+                ((arranger)
+                            (if arranger (set! editing #t))                
+                            (set! choice (get-field (_ "arranger") arranger))
+                    (if choice (set! arranger choice)))
+                ((tagline)
+                            (if tagline (set! editing #t))                
+                            (set! choice (get-field (_ "tagline") tagline))
+                    (if choice (set! tagline choice)))
+                ((copyright)
+                            (if copyright (set! editing #t))                
+                            (set! choice (get-field (_ "copyright") copyright))
+                    (if choice (set! copyright choice)))
+                ((piece)
+                            (if piece (set! editing #t))                
+                            (set! choice (get-field (_ "piece") piece))
+                    (if choice (set! piece choice)))
+                ((opus)
+                            (if opus (set! editing #t))                
+                            (set! choice (get-field (_ "opus") opus))
+                    (if choice (set! opus choice))))
+                    
+             
+             (if (not (eq? choice 'abort))
+                (let ((thealist (string-append "(list " 
+                    (form-pair "dedication" dedication) 
+                    (form-pair "title" title)
+                    (form-pair "subtitle" subtitle)
+                    (form-pair "subsubtitle" subsubtitle)
+                    (form-pair "instrument" instrument)
+                    (form-pair "poet" poet)
+                    (form-pair "composer" composer)
+                    (form-pair "meter" meter)
+                    (form-pair "arranger" arranger)
+                    (form-pair "tagline" tagline)
+                    (form-pair "copyright" copyright)
+                    (form-pair "piece" piece)
+                    (form-pair "opus" opus) " '())")))
+                    (if score
+                        (d-DirectivePut-scoreheader-data tag thealist)
+                        (d-DirectivePut-header-data tag thealist))
+                    (write-titles))))))
+                    
+;;;;;;;;;;;
+(define (DenemoSetVerticalSpacingDist tag type title default)
+    (let ((data (d-DirectiveGet-paper-data tag)))
+        (if (not data)
+            (set! data default))
+        (set! data (d-GetUserInput title (_ "Give Spacing:")  data))
+        (if (and data (string->number data))
+            (begin
+                (d-SetSaved #f)
+                (d-DirectivePut-paper-data tag data)
+                (d-DirectivePut-paper-postfix tag (string-append type ".basic-distance =  " data "\n"))))))
+                
