@@ -14,5 +14,7 @@
         (d-SetSaved #f)
         (d-RefreshDisplay))
     (begin
-        (d-WarningDialog (_ "The cursor is not on a Denemo Directive.\nYou can place the \"Void\"  Denemo Directive before the object you wish to omit\nand then make that directive conditional."))))) 
+      (if (Music?)
+            (d-DirectiveOnlyForLayout #f)
+        (d-WarningDialog (_ "The cursor is not on a Denemo Directive.\nYou can place the \"Hide Next\"  Denemo Directive before the object you wish to omit\nand then make that directive conditional.")))))) 
         
