@@ -6,6 +6,6 @@
 		    (if name
 			(set! name (string-append "\\set PianoStaff.instrumentName = #\"" name "\" "))
 			(set! name ""))
-		    (AttachDirective "staff"  "prefix"  "ContextPianoStaff" (string-append " \\new PianoStaff << " name " \n") DENEMO_OVERRIDE_GRAPHIC DENEMO_OVERRIDE_AFFIX))
+		    (AttachDirective "staff"  "prefix"  "PianoStaffStart" (string-append " \\new PianoStaff << " name " \n") DENEMO_OVERRIDE_GRAPHIC DENEMO_OVERRIDE_AFFIX))
 		  (begin
 		  	(d-WarningDialog "This command must be issued on the first staff of a piano staff group"))))
