@@ -214,9 +214,8 @@ typedef struct
   gint durinticks; /**< Duration of object where 384 (PPQN) is a quarter note, includes any tuplet/grace note effects */
   gint starttick; /**< When the object occurs */ 
   gint starttickofnextnote; /**< When the next object occurs */
-  GList* midi_events;/**< data are the smf_event_ts that this object gives rise to */
-  gdouble earliest_time;/**< cached value of earliest time in midi_events, if no midi_events it holds time of preceding/following midi event   */
-  gdouble latest_time;/**< cached value of latest time in midi_events, if no midi_events it holds time of preceding/following midi event */
+  gdouble earliest_time;/**< time in seconds from start of movement for the start of the note/rest   */
+  gdouble latest_time;/**< time in seconds from start of movement for the end of the note/rest */
   /**< Allots extra space for accidentals or reverse-aligned notes if
    * the stem is down */
   gint space_before; /**< Used to specify how much space is needed before the object in display */
@@ -289,6 +288,7 @@ typedef struct
    */
   gint no_of_lines; /**< Number of lines on the staff */
   gint transposition; /**< Determines if the notes are to be played back at pitch or not */
+  gint color; /**< color to display the staff */
 
   gint volume;  /**< Master Volume used to scale midi playback */
   gboolean override_volume; /**< when true staff plays full Volume always */
@@ -296,18 +296,24 @@ typedef struct
   /* Back to Hiller stuff */
   //  GString *staff_name;
 
-  GString *denemo_name; /**< denemo_name gets copied into lily_name */
-  GString *lily_name; /**< this is the name of the staff that is export to lilypond */
+  GString *denemo_name; /**< partname gets transformed into legitimate lily_name */
+  GString *subpart; /**< distinguishes staffs belonging to one part */
+  GString *lily_name; /**< this is the name of the staff that is exported to lilypond */
   GString *midi_instrument; /**< midi instrument name used for the staff when exported via midi */
   GString *device_port; /**< Device name and Port name concatenated into one string */ 
   gint midi_prognum; /**< midi prognum assigned to the staff voice */
   gint midi_channel; /**< midi channel assigned to the staff voice */
   gint midi_port; /**< midi port assigned to the staff voice */ 
   gint space_above; /**< space above the staff used in the denemo gui */
+  gint space_shorten; /**< space by the staff is shorter in height because of few staff lines */
   gint space_below; /**< space below the staff used in the denemo gui */
+  gboolean range;/**<TRUE if range_hi,lo should be observed. */
+  gint range_hi;/**< highest note playable by instrument, mid_c_offset */
+  gint range_lo;/**< lowest note playable by instrument, mid_c_offset */
   GList *verse_views;/**< a list of text editor widgets each containing a verse */
   GList *current_verse_view;/**< verse to be displayed */
   GList *verses;/**< gchar of the verses, synchronized with GtkTextView buffers */
+  gboolean hide_lyrics; /**< true if lyrics should not be typeset */
   gboolean hasfigures; /**<TRUE if the staff has had figures attached. Only one staff should have this set */
   gboolean hasfakechords; /**<TRUE if the staff has had chord symbols attached. Only one staff should have this set */
   DenemoVoice voicecontrol; /**< either controls whether this staff is displayed and printed separately or as a voice */
@@ -324,7 +330,7 @@ typedef struct
   GList *staff_directives;/**< List of DenemoDirective for the staff context, (only relevant for primary staff)*/
   GList *voice_directives;/**< List of DenemoDirective for the voice context */
 
-  GList *midi_events;/*< cache of midi events to be output at start of the track, after scorewide and movementwide ones created from staff_directives*/
+ 
 
 } DenemoStaff;
 
@@ -469,6 +475,7 @@ typedef struct DenemoPrefs
   gint autosave_timeout;
   gboolean autoupdate;/**< update command set from denemo.org */
   gint maxhistory;/**< how long a history of used files to retain */
+  gint compression;/**< compression to be applied to .denemo files, suffix is unchanged */
   GString *browser; /**< Default browser string */
 
 
@@ -500,6 +507,7 @@ typedef struct DenemoPrefs
   gboolean fluidsynth_chorus; /**< Toggle if chorus is applied to fluidsynth */
 
   gint dynamic_compression;/**< percent compression of dynamic range desired when listening to MIDI-in */
+  gboolean damping;/**< when true notes are re-sounded when left off at a lower velocity depending on their duration */
   gdouble display_refresh;/**< time in ms between refresh of display during playback */
   gint max_menu_size;/** < maximum number of menu entries allowed */
   gint animation_steps;/** < number of steps to use animating the page turns during playback */
@@ -532,7 +540,7 @@ typedef struct DenemoDirective
   GString *display; /**< some text to display to describe the LilyPond attached to the chord */
   gint tx,ty; /**< x and y offsets in pixels for the display text */
   gint minpixels;/**< horizontal space needed by the display */
-  gint x, y; /**< x and y offsets passed to LilyPond to control printed position */
+  guint x /*only_for*/, y /*ignored_by*/; /**< ids of score layouts that are to enable/ignore this directive */
   DenemoGraphic *graphic; /**< what to draw for this directive */
   GtkWidget *widget;  /**<  a button or menu item for accessing the directive for editing or actioning */
   gint gx, gy; /**< x and y offsets in pixels for the graphic */
@@ -692,9 +700,39 @@ typedef struct DenemoPosition { /**<Represents a position in a Score */
   gint object;/**< 0 means no object */
   gboolean appending;/**< if cursor is in appending position */
   gboolean offend;/**< cursor is shown red in this case, obscure connection with appending */
+  gint leftmeasurenum; /**< start at 1 */
 } DenemoPosition;
 
 
+typedef enum
+{
+  STATE_NONE = 0,               //not a background typeset
+  STATE_OFF = 1 << 0,           //background typeset complete
+  STATE_ON = 1 << 1,            //background typeset in progress
+  STATE_PAUSED = 1 << 2         //background typesetting turned off to allow printing
+} background_state;
+
+
+
+typedef struct DenemoPrintInfo
+{
+  GPid printpid;
+  background_state background;
+  gint updating_id;             //id of idle callback
+  gint first_measure;
+  gint last_measure;
+  gint first_staff;
+  gint last_staff;
+  typeset_type typeset_type;
+  gint invalid;                 //set 1 if  lilypond reported problems or 2 if generating new pdf failed 
+  gint cycle;                   //alternate 0 1 to switch print file names
+  gchar *printbasename[2];
+  gchar *printname_pdf[2];
+  gchar *printname_svg[2];
+  gchar *printname_midi[2];
+  gchar *printname_ly[2];
+  gchar *error_file;
+} DenemoPrintInfo;
 /**
  * Contains data required for undo/redo operation 
  * Borrowed idea from GScore
@@ -742,6 +780,7 @@ typedef struct DenemoScoreblock {
   guint32 id;/**< an id for this scoreblock generated from name, as a quick identifier */
   gint movement;/**< Which movement the scoreblock outputs, 0 = all movements. Only used for standard scoreblocks */
   gchar *partname; /**< Which part the scoreblock outputs, NULL = all parts. Only used for standard scoreblocks */
+  gchar *instrumentation;/**< value for the instrumentation value for book titling, taken from the part name */
   gboolean text_only;/**< TRUE if only the lilypond text exists for this widget - no widget structure to be refreshed */
 } DenemoScoreblock;
 
@@ -828,6 +867,12 @@ typedef struct DenemoBrace {
     int starty, endy;
     gboolean curly;
 } DenemoBrace;
+
+typedef struct DenemoScrollPoint {
+     gdouble time, adj;
+     gdouble x, y;
+} DenemoScrollPoint;
+
 /*
  *  DenemoScore structure representing a single movement of a piece of music.
  *  A movement corresponds with a single \score{} block in the LilyPond language
@@ -861,6 +906,7 @@ typedef struct DenemoMovement
   gdouble master_tempo;/**< the tempo used is this times the nominal tempo */
   gdouble tempo_change_time;/**< system time from which the master_tempo is to be used */
   gdouble rightmost_time; /**< MIDI time of rightmost visible object */
+  GList *scroll_points; /**< playback view scroll points for this movement */
 
   gdouble zoom;/**< zoom setting for this movement */
   gdouble preview_zoom; /**< zoom  of print preview pane */
@@ -914,6 +960,7 @@ typedef struct DenemoMovement
    * with its figures staff, if one is present */
   staff_info * has_figures;
   staff_info *has_fakechords;
+
   /* Now stuff that's used for marking areas */
   gint markstaffnum;
   gint markmeasurenum;
@@ -924,7 +971,7 @@ typedef struct DenemoMovement
   movementcontrol movementcontrol;/*< Directives for control of the whole movement */
   layout layout;/*< Directives for the layout block of the movement */
   header header;/*< Directives for the header block of the movement */
-  GList *midi_events;/*< midi_events to be output at start of first track, after scorewide ones */
+  
 
   guint changecount;
   /* Fields used for MIDI playback */
@@ -991,7 +1038,7 @@ typedef struct DenemoProject
   GQueue *pending_midi;/**< a MIDI effect to be output with the next note */
   gboolean audio_recording;
   input_mode mode; /**< Input mode for Score */
-  GtkWidget *progressbar;
+ 
 
   GList *movements;   /**< a list of DenemoMovement, NULL if just one movement */
   DenemoMovement *movement;  /**< the (current)  movement in the musical score controlled by this project */
@@ -999,8 +1046,8 @@ typedef struct DenemoProject
 
   scoreheader scoreheader;/*< Directives for the header block at the start of the score */
   paper paper;/*< Directives for the paper block of the score */
-  GList *midi_events;/*< midi_events to be output at start of first track of each movement */
-    gboolean has_script;/*< true if there is a script to be run on loading the DenemoProject from disk */
+  
+  gboolean has_script;/*< true if there is a script to be run on loading the DenemoProject from disk */
   GList *standard_scoreblocks; /**< List of automatically generated \score blocks for LilyPond output elements are DenemoScoreblock * */
   GList *custom_scoreblocks; /**< List of customized  \score blocks for LilyPond output, elements are DenemoScoreblock * */
   GtkWidget *score_layout; /**< The window in which custom_scoreblock widgets are placed */
@@ -1105,6 +1152,8 @@ struct DenemoRoot
   GtkWidget *printvscrollbar;/**< scrollbar widget for printarea */
   GtkWidget *printhscrollbar;/**< scrollbar widget for printarea */
   GdkPixbuf *pixbuf;/**< print preview pixbuf */
+  GtkWidget *playbackview;/**< area holding svg typeset for animating playback */
+  DenemoPrintInfo *printstatus;/**< Information about the currenty typesetting activity */
   GtkWidget *textwindow; /**< LilyPond output window */
   GtkTextView *textview; /**< LilyPond output text view */
   GtkTextBuffer *textbuffer;   /**< buffer for LilyPond text */
