@@ -394,7 +394,7 @@ pa_main (AubioCallback * fn)
 
 error:
   Pa_Terminate ();
-  fprintf (stderr, "An error occured while using the portaudio stream\n");
+  fprintf (stderr, "An error occurred while using the portaudio stream\n");
   fprintf (stderr, "Error number: %d\n", err);
   fprintf (stderr, "Error message: %s\n", Pa_GetErrorText (err));
   return -1;
