@@ -450,6 +450,7 @@ swapmovements (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam
       gchar *str = g_strdup_printf (_("This movement is now number %d in the score"), 1 + g_list_index (gui->movements, gui->movement));
       infodialog (str);
       g_free (str);
+
       return TRUE;
     }
   else
@@ -1775,8 +1776,9 @@ dnm_insertchord (DenemoProject * gui, gint duration, input_mode mode, gboolean r
             else
                 rhythm_feedback (DEFAULT_BACKEND, duration, rest, FALSE);
         }
-      if (!was_appending)
-        movecursorleft (NULL, NULL);
+    //if (( (!rest) || ((!(mode & INPUTBLANK)) && (!(gui->mode & INPUTBLANK)))) && !was_appending)
+    // if (!was_appending)
+     //   movecursorleft (NULL, NULL);
     }
   else
     {
@@ -1790,6 +1792,8 @@ dnm_insertchord (DenemoProject * gui, gint duration, input_mode mode, gboolean r
                 signal_measure_end();
             }
         }
+   // if (((mode & INPUTBLANK) || (gui->mode & INPUTBLANK)) && !was_appending)
+    //    movecursorleft (NULL, NULL);
     }
 }
 
@@ -2490,7 +2494,7 @@ dnm_deleteobject (DenemoMovement * si)
       DenemoDirective *directive = (lilydirective *) curmudelaobj->object;
       DenemoScriptParam param;
       param.string = g_string_new ("delete");
-      GtkAction *action = lookup_action_from_name (directive->tag->str);
+      GtkAction *action = directive->tag?lookup_action_from_name (directive->tag->str):NULL;
       if (action && (Denemo.keyboard_state != GDK_MOD2_MASK /*NumLock */ ))
         {
           activate_script (action, &param);
