@@ -59,7 +59,8 @@ void delete_chord_or_note_directive (GtkAction * action, DenemoScriptParam * par
 gchar *get_editscript_filename (gchar * tag);
 
 DenemoDirective *get_movementcontrol_directive (gchar * tag);
-DenemoDirective *get_score_directive (gchar * tag); /* others missing here???, note, chord directives for example */
+DenemoDirective *get_score_directive (gchar * tag); 
+DenemoDirective *find_directive (GList * directives, gchar * tag);
 
 gchar *get_nth_strict_note_tag (gint index);
 const gchar *strict_note_directive_get_tag (gchar *tag);
@@ -78,8 +79,22 @@ gchar *get_script_for_directive (DenemoDirective* directive, gchar * what);
 #define DECL_GET_INT(what, field) gint what##_directive_get_##field(gchar *tag);
 #define DECL_PUT_INT(what, field) gboolean what##_directive_put_##field(gchar *tag, gint value);
 
+#define DECL_GET_TAG_FUNC(what) gchar * what##_directive_get_tag(gchar * tag);
+#define DECL_TEXT_EDIT_DIRECTIVE(what) gboolean text_edit_##what##_directive(gchar * tag);
+
 #define DECL_PUT_GRAPHIC(what) gboolean what##_directive_put_graphic(gchar *tag, gchar *value);
 
+DECL_GET_TAG_FUNC (staff)
+DECL_GET_TAG_FUNC (movementcontrol)
+
+DECL_TEXT_EDIT_DIRECTIVE (header)
+DECL_TEXT_EDIT_DIRECTIVE (layout)
+DECL_TEXT_EDIT_DIRECTIVE (movementcontrol)
+DECL_TEXT_EDIT_DIRECTIVE (paper)
+DECL_TEXT_EDIT_DIRECTIVE (scoreheader)
+DECL_TEXT_EDIT_DIRECTIVE (staff)
+DECL_TEXT_EDIT_DIRECTIVE (voice)
+
 DECL_PUT_GRAPHIC (chord)
 DECL_PUT_GRAPHIC (note)
 DECL_PUT_GRAPHIC (standalone)
