@@ -10,7 +10,9 @@
 #include "command/object.h"
 #include "command/staff.h"
 #include "core/utils.h"
-
+#include "command/score.h"
+#include "display/draw.h"
+#include "command/lilydirectives.h"
 static GtkWidget *DummyVerse;   /* a non-existent verse */
 
 GtkWidget*
@@ -29,25 +31,36 @@ void verse_set_current(DenemoStaff* staff, guint id){
     g_debug("Trying to set a verse on an invalid staff");
 }
 
-guint
+gint
 verse_get_current(DenemoStaff* staff){
   return g_list_position(staff->verse_views, staff->current_verse_view);
 }
 
 void 
-verse_set_current_text(DenemoStaff* staff, gchar* text){
-  guint pos = verse_get_current (staff);
-  GList* _current_verse = g_list_nth(staff->verses, pos);
-  if(_current_verse->data)
-    g_free(_current_verse->data);
-  _current_verse->data = text;
+verse_set_current_text(DenemoStaff* staff, gchar* text)
+{
+    if (text) {
+                gint pos = verse_get_current (staff);
+                if (pos>=0)
+                    {
+                    GList* the_current_verse = g_list_nth(staff->verses, pos);
+                    if(the_current_verse->data)
+                        g_free(the_current_verse->data);
+                    the_current_verse->data = text;
+                }
+            }
 }
 
 gchar* 
 verse_get_current_text(DenemoStaff* staff){
-  guint id = verse_get_current (staff);
-  GList* verse =  g_list_nth (staff->verses, id);
-  return (gchar*) verse->data;
+  gint id = verse_get_current (staff);
+  if (id>=0)
+    {
+        GList* verse =  g_list_nth (staff->verses, id);
+        if (verse)
+            return (gchar*) verse->data;
+        }
+    return NULL;
 }
 
 gboolean
@@ -67,7 +80,7 @@ static GtkWidget *
 new_lyric_editor (void)
 {
   GtkWidget *view = gtk_text_view_new ();
-  GtkWidget *sw = gtk_scrolled_window_new (NULL, NULL);
+  GtkWidget *sw = gtk_scrolled_window_new (gtk_adjustment_new (0,0,0,0,0,0), gtk_adjustment_new (0,0,0,0,0,0));
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   if (Denemo.prefs.newbie)
     gtk_widget_set_tooltip_text (sw, _("The text of a verse can be typed or pasted here. Press Esc to return to editing notes.\n"
@@ -157,7 +170,6 @@ get_pos_at_syllable_count (DenemoStaff * staff, gint num, DenemoPosition *pos)
             }
         }                       //for objs
     }                           //for measures
-
   pos->measure = measurenum;
   pos->object = objnum;
 }
@@ -180,7 +192,7 @@ syllable_count (void)
           if (obj->type == CHORD)
             {
               chord *thechord = ((chord *) obj->object);
-              if (thechord->notes && !in_slur)
+              if (thechord->notes && !in_slur && !find_directive (thechord->directives, "MoveRest"))
                 count++;
               if (thechord->slur_begin_p)
                 in_slur = TRUE;
@@ -239,9 +251,16 @@ synchronize_cursor(GtkWidget *textview)
   DenemoPosition pos;
   count = get_syllable_count (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)));
   get_pos_at_syllable_count (thestaff, count, &pos);
-  goto_movement_staff_obj (NULL, 0, Denemo.project->movement->currentstaffnum, pos.measure, pos.object);
+  goto_movement_staff_obj (NULL, 0, Denemo.project->movement->currentstaffnum, pos.measure, pos.object, 0 /* means ignore */);
+}
+static gboolean 
+keypress (GtkWidget *textview, GdkEventKey *event )
+{
+    guint keyval = event->keyval;
+    if (keyval == 0xFF63)
+     return TRUE;// ignore Ins, don't want to have overwrite mode 
+    return FALSE;
 }
-
 static gboolean 
 text_inserted_cb (GtkWidget *textview, GdkEventKey *event )
 {
@@ -264,6 +283,7 @@ text_inserted_cb (GtkWidget *textview, GdkEventKey *event )
     switch_back_to_main_window ();
     return TRUE;
   }
+
   return FALSE;
 }
 
@@ -369,6 +389,8 @@ add_verse_to_staff (DenemoMovement * movement, DenemoStaff * staff)
   GtkTextView* verse_view = (GtkTextView*)verse_get_current_view (staff);
   g_signal_connect (G_OBJECT (gtk_text_view_get_buffer (verse_view)), "changed", G_CALLBACK (lyric_changed_cb), NULL);
   g_signal_connect (G_OBJECT(verse_view), "key-release-event",  G_CALLBACK (text_inserted_cb), NULL);
+  g_signal_connect (G_OBJECT(verse_view), "key-press-event",  G_CALLBACK (keypress), NULL);
+
   g_signal_connect (G_OBJECT(verse_view), "button-release-event",  G_CALLBACK (button_released_cb), NULL);
   g_signal_connect_after (G_OBJECT (verse_view), "populate-popup", G_CALLBACK (populate_called), NULL);
 #if GTK_MAJOR_VERSION==2
@@ -414,7 +436,7 @@ delete_verse (GtkAction * action, DenemoScriptParam * param)
         {
         GtkTextView* verse_view = (GtkTextView*)verse_get_current_view (staff);
         gchar* verse_text = verse_get_current_text (staff);
-        if (verse_view)
+        if (verse_text && verse_view)
             {
               staff->verse_views = g_list_remove (staff->verse_views, verse_view);
               staff->verses = g_list_remove (staff->verses, verse_text);
