@@ -65,8 +65,8 @@ staff_nth_measure_node (staffnode * thestaff, gint n)
 void
 staff_set_current_primary (DenemoMovement * movement)
 {
-  for (movement->currentprimarystaff = movement->currentstaff; !((DenemoStaff *) movement->currentprimarystaff->data)->voicecontrol & DENEMO_PRIMARY; movement->currentprimarystaff = movement->currentprimarystaff->prev)
-    ;
+  for (movement->currentprimarystaff = movement->currentstaff; movement->currentprimarystaff && (((DenemoStaff *) movement->currentprimarystaff->data)->voicecontrol & DENEMO_SECONDARY); movement->currentprimarystaff = movement->currentprimarystaff->prev)
+   ;
 }
 
 /**
@@ -87,7 +87,7 @@ staff_copy_bits (DenemoStaff * src, DenemoStaff * dest)
   dest->volume = 127;
   dest->no_of_lines = 5;
   dest->transposition = 0;
-
+  dest->hide_lyrics = src->hide_lyrics;
   dest->space_above = 0;
   dest->space_below = 0;
   dest->context = DENEMO_NONE;
@@ -104,9 +104,11 @@ staff_copy_properties (DenemoStaff * src, DenemoStaff * dest)
 {
   dest->midi_instrument = g_string_new (src->midi_instrument->str);
   dest->space_above = src->space_above;
+  dest->space_shorten = src->space_shorten;
   dest->space_below = src->space_below;
   dest->no_of_lines = src->no_of_lines;
   dest->transposition = src->transposition;
+  dest->hide_lyrics = src->hide_lyrics;
 
   dest->volume = src->volume;
   dest->voicecontrol = DENEMO_SECONDARY;
@@ -122,8 +124,18 @@ staff_copy (DenemoStaff * src, DenemoStaff * dest)
   dest->denemo_name = g_string_new (src->denemo_name->str);
   dest->lily_name = g_string_new (src->lily_name->str);
   dest->midi_instrument = g_string_new (src->midi_instrument->str);
+  dest->midi_channel = src->midi_channel;
+  dest->midi_prognum = src->midi_prognum;
+  dest->hide_lyrics = src->hide_lyrics;
+  
+  dest->no_of_lines = src->no_of_lines;
   dest->transposition = src->transposition;
-
+  dest->space_above = src->space_above; /**< space above the staff used in the denemo gui */
+  dest->space_shorten = src->space_shorten; /**< space by the staff is shorter in height because of few staff lines */
+  dest->space_below = src->space_below; /**< space below the staff used in the denemo gui */
+  dest->range = src->range;/**<TRUE if range_hi,lo should be observed. */
+  dest->range_hi = src->range_hi;/**< highest note playable by instrument, mid_c_offset */
+  dest->range_lo = src->range_lo;/**< lowest note playable by instrument, mid_c_offset */
   dest->volume = src->volume;
   dest->voicecontrol = src->voicecontrol;
   dest->clef.type = src->clef.type;
