@@ -348,26 +348,18 @@ newVersesElem (xmlNodePtr curElem, xmlNsPtr ns, GList * verses, gchar * type)
   xmlNodePtr versesElem = xmlNewChild (curElem, ns, (xmlChar *) type, NULL);
   for (; verses; verses = verses->next)
     {
-      xmlNewTextChild (versesElem, ns, (xmlChar *) "verse", (xmlChar *) verses->data);
+     if (verses->data && *(xmlChar *)verses->data) //do not create empty verses
+        xmlNewTextChild (versesElem, ns, (xmlChar *) "verse", (xmlChar *) verses->data);
     }
 }
-
-static void
-newDirectivesElem (xmlNodePtr objElem, xmlNsPtr ns, GList * g, gchar * type)
+static void newDirectiveElem (xmlNodePtr directiveElem, xmlNsPtr ns, DenemoDirective *directive) 
 {
-  xmlNodePtr directivesElem = NULL;
-  for (; g; g = g->next)
-    {
-      DenemoDirective *directive = (DenemoDirective *) g->data;
-
 /*      hhmmmm the set_action_script_for_tag is not modifying the directive - just associating a script with the tag. It is when we try to invoke the directive that we find there is an action script */
 /* We Decline to store any directive that has a tag for which an action script is defined in this run of denemo 
 *  this implies people need to be careful in the tags they use for action scripts*/
-      if (directive->tag && get_action_script (directive->tag->str))
-        continue;
-      if (directivesElem == NULL)
-        directivesElem = xmlNewChild (objElem, ns, (xmlChar *) type, NULL);
-      xmlNodePtr directiveElem = xmlNewChild (directivesElem, ns, (xmlChar *) "directive", NULL);
+ 
+
+      
 #define DO_DIREC(field)  if (directive->field \
                    && directive->field->len)\
                       xmlNewTextChild (directiveElem, ns, (xmlChar *) #field,\
@@ -394,6 +386,20 @@ newDirectivesElem (xmlNodePtr objElem, xmlNsPtr ns, GList * g, gchar * type)
 
 #undef DO_DIREC
 #undef DO_INTDIREC
+}
+
+static void
+newDirectivesElem (xmlNodePtr objElem, xmlNsPtr ns, GList * g, gchar * type)
+{
+  xmlNodePtr directivesElem = xmlNewChild (objElem, ns, (xmlChar *) type, NULL);
+
+  for (; g; g = g->next)
+    {
+      DenemoDirective *directive = (DenemoDirective *) g->data;
+      if (directive->tag && get_action_script (directive->tag->str))
+        continue;
+      xmlNodePtr directiveElem = xmlNewChild (directivesElem, ns, (xmlChar *) "directive", NULL);    
+      newDirectiveElem (directiveElem, ns, directive);
     }
 }
 
@@ -577,6 +583,14 @@ newVoiceProps (xmlNodePtr parentElem, xmlNsPtr ns, DenemoStaff * curStaffStruct)
 {
   xmlNodePtr curElem = xmlNewChild (parentElem, ns, (xmlChar *) "voice-props", NULL);
   newXMLIntChild (curElem, ns, (xmlChar *) "number-of-lines", curStaffStruct->no_of_lines);
+  if (curStaffStruct->color)
+    newXMLIntChild (curElem, ns, (xmlChar *) "staff-color", curStaffStruct->color);
+  if (curStaffStruct->range)
+    newXMLIntChild (curElem, ns, (xmlChar *) "staff-range-lo", curStaffStruct->range_lo);
+  if (curStaffStruct->range)
+    newXMLIntChild (curElem, ns, (xmlChar *) "staff-range-hi", curStaffStruct->range_hi);
+  if (curStaffStruct->range)
+    newXMLIntChild (curElem, ns, (xmlChar *) "staff-range", curStaffStruct->range);
   newXMLIntChild (curElem, ns, (xmlChar *) "voice-control", curStaffStruct->voicecontrol);
   newXMLIntChild (curElem, ns, (xmlChar *) "transpose", curStaffStruct->transposition);
   xmlNewChild (curElem, ns, (xmlChar *) "instrument", (xmlChar *) curStaffStruct->midi_instrument->str);
@@ -956,15 +970,21 @@ parseObjects (xmlNodePtr measureElem, xmlNsPtr ns, GList *curObjNode)
 
               break;
             case LILYDIRECTIVE:
+#ifdef OLDSTYLE_STANDALONE_SAVE
               //FIXME this should really have been the tag saved here, but for backwards compatibility we use the postfix string.
               if (((lilydirective *) curObj->object)->postfix && ((lilydirective *) curObj->object)->postfix->len)
                 objElem = xmlNewTextChild (measureElem, ns, (xmlChar *) "lily-directive", (xmlChar *) ((lilydirective *) curObj->object)->postfix->str);
               else
                 objElem = xmlNewTextChild (measureElem, ns, (xmlChar *) "lily-directive", (xmlChar *) " ");
+#else
+                objElem = xmlNewChild (measureElem, ns, (xmlChar *) "lily-directive", NULL);
+                newDirectiveElem (objElem, ns, (lilydirective *) curObj->object);
 
+#endif
               if (((lilydirective *) curObj->object)->locked)
                 xmlSetProp (objElem, (xmlChar *) "locked", (xmlChar *) "true");
 
+#ifdef OLDSTYLE_STANDALONE_SAVE
     #define SETSTRING_PROP(field)\
     if(((lilydirective *) curObj->object)->field && ((lilydirective *) curObj->object)->field->len)\
     xmlSetProp (objElem, (xmlChar *) #field,\
@@ -991,6 +1011,10 @@ parseObjects (xmlNodePtr measureElem, xmlNsPtr ns, GList *curObjNode)
               SETINT_PROP (minpixels);
               SETINT_PROP (override);
     #undef SETINT_PROP
+#endif    
+    
+    
+    
               if (curObj->durinticks)
                 newXMLIntProp (objElem, (xmlChar*) "ticks", curObj->durinticks);
               break;
@@ -1040,6 +1064,28 @@ newRhythmsElem (xmlNodePtr curElem, xmlNsPtr ns, GList *rhythms)
       newRhythmElem (rhythmsElem, ns, r);
     }
 }
+static void
+newScrollPointElem (xmlNodePtr scrollElem, xmlNsPtr ns, DenemoScrollPoint *s)
+{
+  newXMLIntChild (scrollElem, ns, "time", (gint)(1000*(s->time)));
+  newXMLIntChild (scrollElem, ns, "adj", (gint)(1000*(s->adj)));
+  newXMLIntChild (scrollElem, ns, "x", (gint)(1000*(s->x)));
+  newXMLIntChild (scrollElem, ns, "y", (gint)(1000*(s->y)));
+}
+static void
+newScrollPointsElem (xmlNodePtr curElem, xmlNsPtr ns, GList *scroll_points)
+{
+  xmlNodePtr 
+  scrollElem = xmlNewChild (curElem, ns, (xmlChar *) "scroll-points", NULL);
+  for (; scroll_points; scroll_points = scroll_points->next)
+    {
+      DenemoScrollPoint *s = (DenemoScrollPoint*)scroll_points->data;
+      xmlNodePtr  child = xmlNewChild (scrollElem, ns, (xmlChar *) "scroll-point", NULL);
+      newScrollPointElem (child, ns, s);
+    }
+}
+
+
 
 /**
  * Export the given score (from measure start to measure end) as a "native"
@@ -1077,6 +1123,8 @@ exportXML (gchar * thefilename, DenemoProject * gui)
 
   doc = xmlNewDoc ((xmlChar *) "1.0");
   //xmlSetDocCompressMode (doc, XML_COMPRESSION_RATIO);
+  //xmlSetCompressMode (Denemo.prefs.compression);
+  xmlSetDocCompressMode (doc, Denemo.prefs.compression);g_print ("Document compression mode set to %d, (read back as %d)\n", Denemo.prefs.compression, xmlGetDocCompressMode (doc));
   doc->xmlRootNode = scoreElem = xmlNewDocNode (doc, NULL, (xmlChar *) "score", NULL);
   ns = xmlNewNs (doc->xmlRootNode, (xmlChar *) DENEMO_XML_NAMESPACE, NULL);
   xmlSetProp (scoreElem, (xmlChar *) "version", (xmlChar *) version_string);
@@ -1164,6 +1212,9 @@ exportXML (gchar * thefilename, DenemoProject * gui)
         newXMLIntChild (parentElem, ns, (xmlChar *) "page-height", si->page_height);
       if (si->measurewidth != DENEMO_INITIAL_MEASURE_WIDTH)
         newXMLIntChild (parentElem, ns, (xmlChar *) "measure-width", si->measurewidth);
+        
+        
+
 
       if (si->header.directives)
         {
@@ -1178,6 +1229,8 @@ exportXML (gchar * thefilename, DenemoProject * gui)
           newDirectivesElem (mvmntElem, ns, si->movementcontrol.directives, "movementcontrol-directives");
         }
 
+      if (si->scroll_points)
+        newScrollPointsElem (mvmntElem, ns, si->scroll_points);
       // output si->sources
       if (si->sources)
         outputSources (mvmntElem, ns, si->sources);
@@ -1243,6 +1296,8 @@ exportXML (gchar * thefilename, DenemoProject * gui)
 
           parentElem = xmlNewChild (voiceElem, ns, (xmlChar *) "voice-info", NULL);
           xmlNewChild (parentElem, ns, (xmlChar *) "voice-name", (xmlChar *) curStaffStruct->denemo_name->str);
+          if (curStaffStruct->subpart)
+            xmlNewChild (parentElem, ns, (xmlChar *) "subpart", (xmlChar *) curStaffStruct->subpart->str);
           newXMLIntChild (parentElem, ns, (xmlChar *) "first-measure-number", 1);
 
           /*
