@@ -1016,7 +1016,23 @@ parseRest (xmlNodePtr restElem)
       {
         chordObj->basic_durinticks = getXMLIntChild (childElem);
         ((chord *) chordObj->object)->baseduration = -chordObj->basic_durinticks;
-      }
+      }         
+      else if (ELEM_NAME_EQ (childElem, "cresc-begin"))
+          {         
+           ((chord *) chordObj->object)->crescendo_begin_p = TRUE;
+          }
+        else if (ELEM_NAME_EQ (childElem, "cresc-end"))
+          {         
+           ((chord *) chordObj->object)->crescendo_end_p = TRUE;
+          }  
+         else if (ELEM_NAME_EQ (childElem, "dim-begin"))
+          {         
+           ((chord *) chordObj->object)->diminuendo_begin_p = TRUE;
+          }
+        else if (ELEM_NAME_EQ (childElem, "dim-end"))
+          {         
+           ((chord *) chordObj->object)->diminuendo_end_p = TRUE;
+          }  
   }
   return chordObj;
 }
@@ -1061,7 +1077,7 @@ parseSource (xmlNodePtr parentElem)
  * Parse the given sources element.
  * 
  * @param chordElem the XML node to process
- * @param sources the GList* to populate  */
+ * @param  GList  populated  */
 static GList *
 parseSources (xmlNodePtr parentElem)
 {
@@ -1070,7 +1086,37 @@ parseSources (xmlNodePtr parentElem)
   FOREACH_CHILD_ELEM (childElem, parentElem) sources = g_list_append (sources, parseSource (childElem));
   return sources;
 }
+DenemoScrollPoint *parseScrollPoint (xmlNodePtr parentElem)
+{   xmlNodePtr childElem;
+    DenemoScrollPoint *sp = (DenemoScrollPoint*)g_malloc (sizeof (DenemoScrollPoint));
+    FOREACH_CHILD_ELEM (childElem, parentElem)
+        {
+        if (ELEM_NAME_EQ (childElem, "time"))
+          sp->time = getXMLIntChild (childElem)/1000.0; 
+        if (ELEM_NAME_EQ (childElem, "adj"))
+          sp->adj = getXMLIntChild (childElem)/1000.0; 
+        if (ELEM_NAME_EQ (childElem, "x"))
+          sp->x = getXMLIntChild (childElem)/1000.0; 
+        if (ELEM_NAME_EQ (childElem, "y"))
+          sp->y = getXMLIntChild (childElem)/1000.0; 
+        }
+    return sp;
+}
 
+/**
+ * Parse the given Scroll Points element.
+ * 
+ * @param chordElem the XML node to process
+ * @return the GList*   populated   */
+static GList *
+parseScrollPoints (xmlNodePtr parentElem)
+{
+  GList *pts = NULL;
+  xmlNodePtr childElem;
+  FOREACH_CHILD_ELEM (childElem, parentElem) 
+    pts = g_list_append (pts, parseScrollPoint (childElem));
+  return pts;
+}
 static void
 parseAudio (xmlNodePtr parentElem, DenemoMovement * si)
 {
@@ -1105,7 +1151,6 @@ parseChord (xmlNodePtr chordElem, gint currentClef)
 
   FOREACH_CHILD_ELEM (childElem, chordElem)
   {
-   
       {
         if (ELEM_NAME_EQ (childElem, "duration"))
           {
@@ -1220,74 +1265,77 @@ parseLilyDir (xmlNodePtr LilyDirectiveElem)
   gchar *directive = (gchar *) xmlNodeListGetString (LilyDirectiveElem->doc,
                                                      LilyDirectiveElem->xmlChildrenNode,
                                                      1);
-
   DenemoObject *curobj = lily_directive_new (directive ? directive : " ");
   DenemoDirective *thedirective = (lilydirective *) curobj->object;
+  if (directive == NULL)
+    {
+     parseDirective (LilyDirectiveElem, thedirective);
+    } else 
+    { //backward compatibility
 
-  gchar *locked = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) "locked");
 
-  if (locked)
-    thedirective->locked = !strcmp (locked, "true");
-  g_free (locked);
+    #define GET_STR_FIELD(display)\
+      gchar *display = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) #display);\
+      if(display)\
+        ((lilydirective*)curobj->object)->display = g_string_new(display);\
+      g_free(display);
 
-#define GET_STR_FIELD(display)\
-  gchar *display = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) #display);\
-  if(display)\
-    ((lilydirective*)curobj->object)->display = g_string_new(display);\
-  g_free(display);
-
-  GET_STR_FIELD (tag);
-  GET_STR_FIELD (display);
-  GET_STR_FIELD (midibytes);
-  GET_STR_FIELD (grob);
-  GET_STR_FIELD (data);
-  GET_STR_FIELD (graphic_name);
-  GET_STR_FIELD (prefix);
-  if (thedirective->graphic_name && thedirective->graphic_name->len)
-    loadGraphicItem (thedirective->graphic_name->str, (DenemoGraphic **) & thedirective->graphic);
-    
-   if(version_number < 7) {
-       GString *lily = ((lilydirective*)curobj->object)->postfix;
-       //convert old style barlines to LilyPond 2.18 style
-       if(lily)
-       {
-        gchar *postfix = lily->str;
-        if (!g_strcmp0 ("\\bar \":|\"", postfix))
-            g_string_assign(lily, "\\bar \":|.\"");
-        else if (!g_strcmp0 (" \\bar \"|:\"", postfix))//Note there was a space in the old directive before \bar!
-            g_string_assign(lily, "\\bar \".|:\"");
-        else if (!g_strcmp0 ("\\bar \"|:\"", postfix))//for versions without the space
-            g_string_assign(lily, "\\bar \".|:\"");
-        else if (!g_strcmp0 (" \\bar \":|:\"", postfix)) //Note there was a space in (some versions of?) the old directive!
-            g_string_assign(lily, "\\bar \":..:\"");
-        else if (!g_strcmp0 ("\\bar \":|:\"", postfix))
-            g_string_assign(lily, "\\bar \":..:\"");
+      GET_STR_FIELD (tag);
+      GET_STR_FIELD (display);
+      GET_STR_FIELD (midibytes);
+      GET_STR_FIELD (grob);
+      GET_STR_FIELD (data);
+      GET_STR_FIELD (graphic_name);
+      GET_STR_FIELD (prefix);
+      if (thedirective->graphic_name && thedirective->graphic_name->len)
+        loadGraphicItem (thedirective->graphic_name->str, (DenemoGraphic **) & thedirective->graphic);
         
-       }
-   } 
-    
-    
-#define GET_INT_FIELD(x)\
-  gchar *x = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) #x);\
-  if(x)\
-    thedirective->x = atoi(x);\
-  g_free(x);
+       if(version_number < 7) {
+           GString *lily = ((lilydirective*)curobj->object)->postfix;
+           //convert old style barlines to LilyPond 2.18 style
+           if(lily)
+           {
+            gchar *postfix = lily->str;
+            if (!g_strcmp0 ("\\bar \":|\"", postfix))
+                g_string_assign(lily, "\\bar \":|.\"");
+            else if (!g_strcmp0 (" \\bar \"|:\"", postfix))//Note there was a space in the old directive before \bar!
+                g_string_assign(lily, "\\bar \".|:\"");
+            else if (!g_strcmp0 ("\\bar \"|:\"", postfix))//for versions without the space
+                g_string_assign(lily, "\\bar \".|:\"");
+            else if (!g_strcmp0 (" \\bar \":|:\"", postfix)) //Note there was a space in (some versions of?) the old directive!
+                g_string_assign(lily, "\\bar \":..:\"");
+            else if (!g_strcmp0 ("\\bar \":|:\"", postfix))
+                g_string_assign(lily, "\\bar \":..:\"");
+            
+           }
+       } 
+        
+        
+    #define GET_INT_FIELD(x)\
+      gchar *x = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) #x);\
+      if(x)\
+        thedirective->x = atoi(x);\
+      g_free(x);
 
-  GET_INT_FIELD (x);
-  GET_INT_FIELD (y);
-  GET_INT_FIELD (tx);
-  GET_INT_FIELD (ty);
-  GET_INT_FIELD (gx);
-  GET_INT_FIELD (gy);
-  GET_INT_FIELD (override);
-  UPDATE_OVERRIDE (thedirective);
-  GET_INT_FIELD (minpixels);
-  // curobj->minpixelsalloted = thedirective->minpixels?thedirective->minpixels:16;//FIXME setpixelmin
-  setpixelmin (curobj);
-  gchar *ticks = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) "ticks");
-  if (ticks)
+      GET_INT_FIELD (x);
+      GET_INT_FIELD (y);
+      GET_INT_FIELD (tx);
+      GET_INT_FIELD (ty);
+      GET_INT_FIELD (gx);
+      GET_INT_FIELD (gy);
+      GET_INT_FIELD (override);
+      UPDATE_OVERRIDE (thedirective);
+      GET_INT_FIELD (minpixels);
+    }// end of backward compatibility
+  
+    setpixelmin (curobj);
+    gchar *locked = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) "locked");
+    if (locked)
+    thedirective->locked = !strcmp (locked, "true");
+    g_free (locked);
+    gchar *ticks = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) "ticks");
+    if (ticks)
     curobj->durinticks = atoi (ticks);
-  //curobj->baseduration = - curobj->durinticks;
   return curobj;
 }
 
@@ -1540,7 +1588,7 @@ parseSetupInfo (xmlNodePtr editInfoElem, DenemoProject * gui)
               }
         else if (ELEM_NAME_EQ (childElem, "score-directives"))
           {
-            gui->lilycontrol.directives = parseWidgetDirectives (childElem, (gpointer) score_directive_put_graphic, NULL, NULL);
+            gui->lilycontrol.directives = parseWidgetDirectives (childElem, (gpointer) score_directive_put_graphic, NULL, &(gui->lilycontrol.directives));
           }
 
 
@@ -1819,6 +1867,7 @@ parseStaff (xmlNodePtr staffElem, DenemoMovement * si)
                 curStaff->no_of_lines = 5;
               }
           }
+
         else if (ELEM_NAME_EQ (childElem, "volume"))
           {
             curStaff->volume = getXMLIntChild (childElem);
@@ -2006,6 +2055,22 @@ parseVoiceProps (xmlNodePtr voicePropElem, DenemoMovement * si)
             curStaff->no_of_lines = 5;
           }
       }
+    else if (ELEM_NAME_EQ (childElem, "staff-color"))
+      {
+        curStaff->color = getXMLIntChild (childElem);
+      }
+    else if (ELEM_NAME_EQ (childElem, "staff-range"))
+      {
+        curStaff->range = getXMLIntChild (childElem);
+      }
+    else if (ELEM_NAME_EQ (childElem, "staff-range-lo"))
+      {
+        curStaff->range_lo = getXMLIntChild (childElem);
+      }
+    else if (ELEM_NAME_EQ (childElem, "staff-range-hi"))
+      {
+        curStaff->range_hi = getXMLIntChild (childElem);
+      }
     else if (ELEM_NAME_EQ (childElem, "voice-control"))
       {
         curStaff->voicecontrol = getXMLIntChild (childElem);
@@ -2110,7 +2175,7 @@ static gint
 parseVoiceInfo (xmlNodePtr voiceInfoElem, DenemoMovement * si)
 {
   xmlNodePtr childElem;
-  gchar *voiceName;
+  gchar *voiceName, *subpart;
 
   FOREACH_CHILD_ELEM (childElem, voiceInfoElem)
   {
@@ -2127,6 +2192,20 @@ parseVoiceInfo (xmlNodePtr voiceInfoElem, DenemoMovement * si)
                 set_lily_name (thestaffstruct->denemo_name, thestaffstruct->lily_name);
               }
           }
+        
+        else if (ELEM_NAME_EQ (childElem, "subpart"))
+          {
+            subpart = (gchar *) xmlNodeListGetString (childElem->doc, childElem->xmlChildrenNode, 1);
+            if (subpart != NULL)
+              {
+                DenemoStaff *thestaffstruct = (DenemoStaff *) si->currentstaff->data;
+                if(thestaffstruct->subpart)
+                    g_string_assign (thestaffstruct->subpart, subpart);
+                else
+                    thestaffstruct->subpart = g_string_new (subpart);
+                g_free (subpart);
+              }
+          }
         else if (ELEM_NAME_EQ (childElem, "first-measure-number"))
           {
             /* Do nothing (yet).  All voices start at measure 1. */
@@ -2398,7 +2477,7 @@ parseMeasures (xmlNodePtr measuresElem, DenemoMovement * si)
           {
 
             si->currentmeasure = dnm_addmeasures (si, si->currentmeasurenum - 1, 1, FALSE);
-            g_debug ("ImportXML Adding Measure \n currentmeasurenum %d", si->currentmeasurenum);
+            //g_debug ("ImportXML Adding Measure \n currentmeasurenum %d", si->currentmeasurenum);
           }
           
         si->currentmeasure->data = parseMeasure (childElem, &currentClef, 
@@ -2559,6 +2638,11 @@ parseScore (xmlNodePtr scoreElem, DenemoProject * gui, ImportType type)
   if (type == REPLACE_SCORE)
     if (parseScoreInfo (childElem, si) != 0)
       return -1;
+      
+    childElem = getXMLChild (scoreElem, "scroll-points");   
+   if (childElem)
+        si->scroll_points = parseScrollPoints (childElem);
+      
 
   /*
    * Note: We don't currently care about <staves>, but we will need to
@@ -2589,11 +2673,13 @@ parseScore (xmlNodePtr scoreElem, DenemoProject * gui, ImportType type)
 static gint
 parseMovement (xmlNodePtr childElem, DenemoProject * gui, ImportType type)
 {
-  int ret = 0;
-
+  gint ret = 0;
+  gint previous_staffnum = 0;
   DenemoMovement *si = gui->movement;
   if (type != ADD_STAFFS)
     gui->movements = g_list_append (gui->movements, gui->movement);
+  else
+    previous_staffnum = g_list_length(si->thescore);
   si->currentstaffnum = 0;
   sPrevStaffElem = NULL;
   ret = parseScore (childElem, gui, type);
@@ -2604,8 +2690,15 @@ parseMovement (xmlNodePtr childElem, DenemoProject * gui, ImportType type)
       g_warning ("Bad Denemo file");
       return -1;
     }
+  if (previous_staffnum)
+    {
+        curstaff = g_list_nth (si->thescore, previous_staffnum);
+        for(;curstaff;curstaff=curstaff->next)
+            ((DenemoStaff *) curstaff->data)->midi_channel = ((previous_staffnum) < 9 ? (previous_staffnum) : previous_staffnum + 1) & 0xF;
+    }
   for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
     {
+    
       staff_beams_and_stems_dirs ((DenemoStaff *) curstaff->data);
       staff_show_which_accidentals ((DenemoStaff *) curstaff->data);
     }
@@ -2633,6 +2726,7 @@ parseMovement (xmlNodePtr childElem, DenemoProject * gui, ImportType type)
   set_rightmeasurenum (gui->movement);
   set_bottom_staff (gui);
   set_width_to_work_with (gui);
+
   return ret;
 }
 
@@ -2741,7 +2835,10 @@ importXML (gchar * filename, DenemoProject * gui, ImportType type)
   sscanf (version, "%d", &version_number);
   if (version_number > CURRENT_XML_VERSION)
     {
-      g_warning ("Denemo XML file version %d found, but we can only handle %d and lower", version_number, CURRENT_XML_VERSION);
+      gchar *text = g_strdup_printf ("Denemo file format version %d found, but this version of Denemo (%s) can only load denemo file version %d or lower. Update to a newer Denemo release.", version_number, PACKAGE_VERSION, CURRENT_XML_VERSION);
+       
+      warningdialog (text);
+      g_free (text);
       ret = -1;
       goto cleanup;
     }
