@@ -8,10 +8,13 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <ctype.h>
+#include <stdlib.h>
 #include <math.h>
 #include "display/calculatepositions.h"
 #include "command/commandfuncs.h"
 #include "command/contexts.h"
+#include "command/lilydirectives.h"
 #include "display/draw.h"               /* Which includes gtk.h */
 #include "display/drawingprims.h"
 #include "display/slurs.h"
@@ -54,8 +57,21 @@ set_start_and_end_objects_for_draw (void)
 {
   if (Denemo.project->movement->smf)
     {
-      Startobj = get_obj_for_end_time (Denemo.project->movement->smf, Denemo.project->movement->start_time/get_playback_speed() + 0.001);
-      Endobj = Denemo.project->movement->end_time < 0.0 ? NULL : get_obj_for_start_time (Denemo.project->movement->smf, Denemo.project->movement->end_time/get_playback_speed() - 0.001);
+      gdouble start = Denemo.project->movement->start_time;
+      gdouble end = Denemo.project->movement->end_time;
+      if ((end > 0.0) && (end < start))
+        {
+#ifdef SWAPPING_ENDS
+            Denemo.project->movement->start_time = end;
+            Denemo.project->movement->end_time = start;
+            start = Denemo.project->movement->start_time;
+            end = Denemo.project->movement->end_time;
+#else
+            Denemo.project->movement->end_time = -1.0;
+#endif
+        }
+      Startobj = get_obj_for_end_time (Denemo.project->movement->smf, start/get_playback_speed() + 0.001);
+      Endobj = Denemo.project->movement->end_time < 0.0 ? NULL : get_obj_for_start_time (Denemo.project->movement->smf, end/get_playback_speed() - 0.001);
     }
 }
 
@@ -152,6 +168,9 @@ struct infotopass
   gint currentframe; //current frame of audio being played. (current time converted to frames (at si->recording->samplerate) and slowed down)
   gboolean highlight_next_note;//the last CHORD was the one before the currently playing one.
   gboolean allow_duration_error; //do not indicate errors in duration of measure
+  gdouble red, green, blue, alpha; //color of notes
+  gboolean range;
+  gint range_lo, range_hi;
 };
 
 /* count the number of syllables up to staff->leftmeasurenum */
@@ -178,7 +197,7 @@ count_syllables (DenemoStaff * staff, gint from)
                 in_slur = TRUE;
               if (thechord->slur_end_p)
                 in_slur = FALSE;
-              if (thechord->is_tied)
+              if (thechord->is_tied && (!in_slur))
                 count--;
             }
         }                       //for objs
@@ -301,24 +320,32 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
     if (mudelaitem->type == CHORD && ((chord *) mudelaitem->object)->tone_node)
       cairo_set_source_rgb (cr, 231.0 / 255, 215.0 / 255, 39.0 / 255);  //thecolor = &yellow;
 
-  if (mudelaitem->midi_events)
-    {
-      itp->last_midi = mudelaitem->midi_events;
-    }
+
 
   switch (mudelaitem->type)
     {
     case CHORD:
       {
         chord *thechord = ((chord *) mudelaitem->object);
-
+        if(cr)
+           {
+            cairo_save (cr);
+            //if staff->range and thechord->highesty staff->range_hi ...
+            if (itp->range && ((thechord->highestpitch > itp->range_hi) || (thechord->lowestpitch < itp->range_lo)))
+                cairo_set_source_rgba (cr, 1.0, 0.0, 0.0, 1.0);
+            else
+                cairo_set_source_rgba (cr, itp->red, itp->green, itp->blue, itp->alpha);
+           }
         gint highest = draw_chord (cr, curobj, x + mudelaitem->x, y,
                                    GPOINTER_TO_INT (itp->mwidthiterator->data),
                                    itp->curaccs, itp->mark, (si->currentobject == curobj));
+        if(cr)
+           {
+            cairo_restore (cr);
+           }             
         if ((thechord->highesty) < itp->highy)
           itp->highy = thechord->highesty;
         itp->highy = MIN (itp->highy, highest);
-        //g_debug("highy %d\n", itp->highy);
         if ((thechord->lowesty) > itp->lowy + STAFF_HEIGHT)
           itp->lowy = thechord->lowesty - STAFF_HEIGHT;
  
@@ -471,7 +498,7 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
                 }
             itp->recordednote = g;//Search onwards for future onsets. Only notes on top staff are used for display of onsets. 
 
-         } 
+         } //recording
           
 
         if (itp->tupletstart)
@@ -484,7 +511,7 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
         if (si->currentstaffnum == itp->staffnum && itp->verse && thechord->notes)
           {
             static gboolean last_tied = FALSE;
-            if ((!last_tied) && (!itp->slur_stack) && (!thechord->is_tied))
+            if ((!last_tied) && (!itp->slur_stack) && (!thechord->is_tied) && !find_directive (thechord->directives, "MoveRest"))
               {
                 gchar *syllable = (gchar *) next_syllable ();
                 if (cr)
@@ -504,45 +531,78 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
         if (thechord->slur_begin_p)
           itp->slur_stack = push_slur_stack (itp->slur_stack, x + mudelaitem->x, thechord->highesty);
 
+
+
+
         if (thechord->crescendo_begin_p)
           {
+           if (thechord->diminuendo_end_p)
+              {
+               if (top_hairpin_stack (itp->hairpin_stack) == -1)
+                    {
+                        itp->hairpin_stack = push_hairpin_stack (itp->hairpin_stack, -10);
+                    }
+              if (cr) draw_hairpin (cr, &(itp->hairpin_stack), x + mudelaitem->x, y, 0);
+                   //pop stack
+              itp->hairpin_stack = pop_hairpin_stack (itp->hairpin_stack);      
+             } else  if (thechord->crescendo_end_p)
+              {
+                if (top_hairpin_stack (itp->hairpin_stack) == -1)
+                  {
+                        itp->hairpin_stack = push_hairpin_stack (itp->hairpin_stack, -10);
+                  }
+                if (cr) draw_hairpin (cr, &(itp->hairpin_stack), x + mudelaitem->x, y, 1);
+                   //pop stack
+                itp->hairpin_stack = pop_hairpin_stack (itp->hairpin_stack);
+             }
             itp->hairpin_stack = push_hairpin_stack (itp->hairpin_stack, x + mudelaitem->x);
           }
         else if (thechord->diminuendo_begin_p)
           {
+            if (thechord->crescendo_end_p)
+              {
+                if (top_hairpin_stack (itp->hairpin_stack) == -1)
+                  {
+                        itp->hairpin_stack = push_hairpin_stack (itp->hairpin_stack, -10);
+                  }
+                if (cr) draw_hairpin (cr, &(itp->hairpin_stack), x + mudelaitem->x, y, 1);
+                   //pop stack
+                itp->hairpin_stack = pop_hairpin_stack (itp->hairpin_stack);
+             } else if (thechord->diminuendo_end_p)
+              {
+               if (top_hairpin_stack (itp->hairpin_stack) == -1)
+                    {
+                        itp->hairpin_stack = push_hairpin_stack (itp->hairpin_stack, -10);
+                    }
+              if (cr) draw_hairpin (cr, &(itp->hairpin_stack), x + mudelaitem->x, y, 0);
+                   //pop stack
+              itp->hairpin_stack = pop_hairpin_stack (itp->hairpin_stack);      
+             } 
             itp->hairpin_stack = push_hairpin_stack (itp->hairpin_stack, x + mudelaitem->x);
           }
-
-        if (cr)
+       else
           {
             if (thechord->crescendo_end_p)
               {
-                if (top_hairpin_stack (itp->hairpin_stack) <= -1)
+                 if (top_hairpin_stack (itp->hairpin_stack) == -1)
                   {
-#if 0
-                    //this is only the visible part of the cresc, the start may be off screen
-                    thechord->crescendo_end_p = FALSE;
-                    warningdialog (_("Crescendo end without a corresponding start\n" "removing the crescendo end"));
-#endif
+                        itp->hairpin_stack = push_hairpin_stack (itp->hairpin_stack, -10);
                   }
-                draw_hairpin (cr, &(itp->hairpin_stack), x + mudelaitem->x, y, 1);
+                if (cr) draw_hairpin (cr, &(itp->hairpin_stack), x + mudelaitem->x, y, 1);
+                   //pop stack
+                itp->hairpin_stack = pop_hairpin_stack (itp->hairpin_stack);
               }
             else if (thechord->diminuendo_end_p)
               {
-                if (top_hairpin_stack (itp->hairpin_stack) <= -1)
-                  {
-#if 0
-                    //this is only the visible part of the dim, the start may be off screen
-                    thechord->diminuendo_end_p = FALSE;
-                    warningdialog (_("Diminuendo end without a corresponding start\n" "removing the diminuendo end"));
-#endif
-                  }
-                draw_hairpin (cr, &(itp->hairpin_stack), x + mudelaitem->x, y, 0);
+               if (top_hairpin_stack (itp->hairpin_stack) == -1)
+                    {
+                        itp->hairpin_stack = push_hairpin_stack (itp->hairpin_stack, -10);
+                    }
+               if (cr) draw_hairpin (cr, &(itp->hairpin_stack), x + mudelaitem->x, y, 0);
+                   //pop stack
+               itp->hairpin_stack = pop_hairpin_stack (itp->hairpin_stack);       
               }
-          }                     // if cr
-
-
-
+          }
         /* notice the following does not check is_figure but checks if figure is not VOID) */
         //if (!thechord->is_figure && thechord->figure)
         if (cr)
@@ -878,7 +938,13 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
   gboolean repeat = FALSE;
   DenemoMovement *si = gui->movement;
   gint x = (gui->leftmargin+35), i;
-
+    itp->red = (((thestaff->color)>>24)&0xFF)/255.0;
+    itp->green = (((thestaff->color)>>16)&0xFF)/255.0;
+    itp->blue = (((thestaff->color)>>8)&0xFF)/255.0;
+    itp->alpha = (0xFF ^ ((thestaff->color)&0xFF))/255.0;
+    itp->range = thestaff->range;
+    itp->range_lo = thestaff->range_lo;
+    itp->range_hi = thestaff->range_hi;
   // if(si->marked_onset_position)
     //g_debug("repeat"),repeat = TRUE;//we set up the marked onset with this, then need to repeat to draw it
   //g_debug("drawing staff %d at %d\n", itp->staffnum, y);
@@ -912,8 +978,11 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
         cairo_set_source_rgb (cr, 0, 0, 0);
       else
         cairo_set_source_rgb (cr, 0.3, 0.3, 0.3);
-    }                           //if cr
+    }   //if cr
 
+ 
+
+    
   if (!itp->line_end)
     {                           //not a continuation
       itp->clef = thestaff->leftmost_clefcontext;
@@ -978,6 +1047,8 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
            if (si->leftmeasurenum == 1)//make a button of it if measure 1 is leftmost 
              {
               drawnormaltext_cr (cr, thestaff->denemo_name->str, gui->leftmargin /*KEY_MARGIN */ , y - staffname_offset + 10); 
+              if (thestaff->subpart)
+                drawnormaltext_cr (cr, thestaff->subpart->str, gui->leftmargin +20/*KEY_MARGIN */ , y - staffname_offset + 20); 
               cairo_save (cr);
               cairo_set_source_rgba (cr, 0.2, 0.8, 0.4, 0.4);
               cairo_rectangle (cr, gui->leftmargin, y - staffname_offset - 0, 30, 12);
@@ -987,8 +1058,12 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
               cairo_stroke (cr);
               cairo_restore(cr);
              }
-            else
+           else
+             {
               drawnormaltext_cr (cr, thestaff->denemo_name->str, gui->leftmargin - 10 /*KEY_MARGIN */ , y - staffname_offset + 10); 
+              if (thestaff->subpart)
+                drawnormaltext_cr (cr, thestaff->subpart->str, gui->leftmargin + 20 /*KEY_MARGIN */ , y - staffname_offset + 20); 
+             }
             if(thestaff->hasfakechords)  drawnormaltext_cr (cr, _("Chord Symbols"), gui->leftmargin - 10 /*KEY_MARGIN */ , y - staffname_offset + 20 + 2 * STAFF_HEIGHT); 
             if(thestaff->hasfigures)  drawnormaltext_cr (cr, _("Figured Bass"), gui->leftmargin - 10 /*KEY_MARGIN */ , y - staffname_offset + 20 + 2 * STAFF_HEIGHT); 
         }
@@ -999,6 +1074,8 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
           cairo_translate (cr, 2, (y - staffname_offset + 30));
           cairo_rotate (cr, -M_PI / 5.0);
           drawnormaltext_cr (cr, thestaff->denemo_name->str, 0, 0);
+          if (thestaff->subpart)
+                drawnormaltext_cr (cr, thestaff->subpart->str, 30, 20); 
           cairo_restore (cr);
         }
     }                           //if cr
@@ -1355,7 +1432,7 @@ draw_score (cairo_t * cr)
         {
         DenemoStaff* staff = (DenemoStaff*)curstaff->data;
         gchar *context;
-        
+
           for (g = staff->staff_directives; g; g = g->next)
             {
               DenemoDirective *directive = g->data;
@@ -1432,6 +1509,8 @@ draw_score (cairo_t * cr)
   for (itp.staffnum = si->top_staff, curstaff = g_list_nth (si->thescore, si->top_staff - 1), (y += si->staffspace / 4); curstaff && itp.staffnum <= si->bottom_staff;  curstaff = curstaff->next, itp.staffnum++)
     {
       DenemoStaff *staff = (DenemoStaff *) curstaff->data;
+      g_slist_free (itp.hairpin_stack);//clear any cresc or dim started but not finished; these can just be off-screen, they need not be in error.
+      itp.hairpin_stack = NULL;
       if(cr) if (staff->hidden) 
       {
         gboolean current =  (si->currentstaffnum == itp.staffnum);
@@ -1474,7 +1553,7 @@ draw_score (cairo_t * cr)
             cairo_fill (cr);
             cairo_restore (cr);
 
-            if (staff->staff_directives)
+            if (staff->staff_directives, 1)
               {
 
                 guint width = gdk_pixbuf_get_width (GDK_PIXBUF (StaffDirectivesPixbuf));
@@ -1492,7 +1571,7 @@ draw_score (cairo_t * cr)
                 cairo_restore (cr);
                 //gdk_draw_pixbuf(Denemo.pixmap, NULL, StaffDirectivesPixbuf,  0,0, 0,y, width, height, GDK_RGB_DITHER_NONE,0,0/*staff edit*/);
               }
-            if (staff->voice_directives)
+            if (staff->voice_directives, 0)
               {
 
                 guint width = gdk_pixbuf_get_width (GDK_PIXBUF (StaffDirectivesPixbuf));
@@ -1680,8 +1759,13 @@ draw_score (cairo_t * cr)
             {
               y += LYRICS_HEIGHT;
             }
-          y += (si->staffspace + staff->space_below);
-        }
+        if (curstaff->next)
+        {
+          DenemoStaff *next = (DenemoStaff *) (curstaff->next->data);
+          y += (si->staffspace - next->space_shorten + staff->space_below);
+        } else
+         y += (si->staffspace + staff->space_below);
+      }
      
     }                           // for all the staffs
 
@@ -1718,13 +1802,9 @@ draw_callback (cairo_t * cr)
         update_vscrollbar (gui);
       }
   layout_needed = TRUE;
-#if 0
- if( gui->movement->recording && (gui->movement->smfsync != gui->movement->changecount) && (!audio_is_playing())) 
- {
-     set_tempo ();
-     exportmidi (NULL, gui->movement, 0, 0);  
- }
-#endif
+  if(Denemo.project->movement->playingnow)
+    gtk_widget_queue_draw (Denemo.playbackview);
+  
   /* Clear with an appropriate background color. */
   if (((DenemoStaff*)Denemo.project->movement->currentstaff->data)->hidden)
     cairo_set_source_rgb (cr, 1, 0.8, 0.8);
