@@ -61,6 +61,7 @@
 #include "audio/instrumentname.h"
 #include "audio/audiointerface.h"
 #include "core/view.h"
+#include "printview/svgview.h"
 #include "smf.h"
 /* 
  * only for developers
@@ -713,7 +714,7 @@ is_status_byte(const unsigned char status)
    and frees buffer. Returns the event, or NULL if invalid buffer.
  */
 static smf_event_t *
-put_event (gchar * buffer, gint numbytes, GList ** midi_events, smf_track_t * track)
+put_event (gchar * buffer, gint numbytes,  smf_track_t * track)
 {
   smf_event_t *event = NULL;
   if (numbytes && is_status_byte (buffer[0]))
@@ -721,7 +722,6 @@ put_event (gchar * buffer, gint numbytes, GList ** midi_events, smf_track_t * tr
  if (event && smf_event_is_valid (event))
     {
       smf_track_add_event_delta_pulses (track, event, 0);
-      *midi_events = g_list_append (*midi_events, event);
     }
   g_free (buffer);
   return event;
@@ -890,6 +890,68 @@ change_tempo (gint * tempo, gint midi_val, gint midi_interpretation, gint midi_a
     }
 }
 
+static void load_smf ( DenemoMovement *si, smf_t *smf)
+  {
+    if (si->smf==smf)
+       return;
+    gboolean midi_track = FALSE;
+    
+
+    g_static_mutex_lock (&smfmutex);
+    if (Denemo.project->movement->recorded_midi_track)
+      {
+        if (si->smf && (((smf_track_t *) Denemo.project->movement->recorded_midi_track)->smf == si->smf))
+          {
+            smf_track_remove_from_smf (Denemo.project->movement->recorded_midi_track);
+            midi_track = TRUE;
+          }
+      }
+    free_midi_data (si);
+    si->smf = smf;
+    if (midi_track)
+      smf_add_track (smf, Denemo.project->movement->recorded_midi_track);
+
+
+    si->smfsync = si->changecount;
+    g_static_mutex_unlock (&smfmutex);
+  }
+  
+
+static void save_smf_to_file (smf_t *smf, gchar *thefilename)
+{
+  if (thefilename)
+    {
+      if (Denemo.project->movement->recorded_midi_track)
+        smf_add_track (smf, Denemo.project->movement->recorded_midi_track);
+      if(smf_save (smf, (const char *) thefilename))
+        g_debug("smf_save failed");
+      if (Denemo.project->movement->recorded_midi_track)
+        smf_track_remove_from_smf (Denemo.project->movement->recorded_midi_track);
+    }
+}
+
+gdouble load_lilypond_midi (gchar * outfile, gboolean keep) {
+    smf_t *saved = NULL;
+    gchar *midi_file = Denemo.printstatus->printname_midi[Denemo.printstatus->cycle];
+    smf_t *smf = smf_load (midi_file);
+    if (smf)
+        {
+        if (!attach_timings ())
+            g_warning ("Attaching timings to objects failed\n");              
+        if (outfile)
+            save_smf_to_file (smf, outfile);             
+        if (!keep )
+            load_smf (Denemo.project->movement, smf);
+        else 
+            smf_delete (smf);
+        return smf_get_length_seconds (Denemo.project->movement->smf);
+    } else
+    {
+        g_warning ("midi file %s not loaded", midi_file);
+    }
+    return 0.0;
+}
+  
 /*
  * the main midi output system (somewhat large)
  */
@@ -903,7 +965,7 @@ change_tempo (gint * tempo, gint midi_val, gint midi_interpretation, gint midi_a
  * return the duration in seconds of the music stored
  */
 gdouble
-exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
+exportmidi (gchar * thefilename, DenemoMovement * si)
 {
   /* variables for reading and decoding the object list */
   smf_event_t *event = NULL;
@@ -1095,7 +1157,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
               gchar *buf = directive_get_midi_buffer (directive, &numbytes, midi_channel, cur_volume);
               if (!(midi_override & DENEMO_OVERRIDE_HIDDEN))
                 if (buf)
-                  if (NULL == put_event (buf, numbytes, &curstaffstruct->midi_events, track))
+                  if (NULL == put_event (buf, numbytes, track))
                     g_warning ("Invalid midi bytes in staff directive");
             }
         }
@@ -1116,7 +1178,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                   gchar *buf = directive_get_midi_buffer (directive, &numbytes, midi_channel, cur_volume);
                   if (!(midi_override & DENEMO_OVERRIDE_HIDDEN))
                     if (buf)
-                      if (NULL == put_event (buf, numbytes, &Denemo.project->midi_events, track))
+                      if (NULL == put_event (buf, numbytes, track))
                         g_warning ("Invalid midi bytes in score directive");
                 }
             }
@@ -1133,7 +1195,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                   gchar *buf = directive_get_midi_buffer (directive, &numbytes, midi_channel, cur_volume);
                   if (!(midi_override & DENEMO_OVERRIDE_HIDDEN))
                     if (buf)
-                      if (NULL == put_event (buf, numbytes, &Denemo.project->movement->midi_events, track))
+                      if (NULL == put_event (buf, numbytes,  track))
                         g_warning ("Invalid midi bytes in movement directive");
                 }
             }
@@ -1156,20 +1218,13 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
       slur_erase (note_status, &slur_status);
 
       /* set boundries */
-      if (!end)
-        last = g_list_length (curmeasure);
-      else
-        last = end;
-      if (start)
-        curmeasure = g_list_nth (curmeasure, start - 1);
+     
+      last = g_list_length (curmeasure);
+      
+
       /* iterate for over measures in track */
-      for (measurenum = MAX (start, 1); curmeasure && measurenum <= last; curmeasure = curmeasure->next, measurenum++)
+      for (measurenum = 1; curmeasure && measurenum <= last; curmeasure = curmeasure->next, measurenum++)
         {
-          //printf
-          //  ("\nMAX start,1, curmeasurenum, last in export midi is = %i, %i, %i\n",
-          //   MAX (start, 1), curmeasurenum, last);
-          //printf("\ncurmeasure && measurenum in export midi is = %i\n", (curmeasure && measurenum));
-          //printf("\ncurmeasurenum in export midi is = %i\n", curmeasurenum);
           /* start of measure */
           curmeasurenum++;
           measure_is_empty = 1;
@@ -1180,9 +1235,6 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
           for (curobjnode = (objnode *) curmeasure->data; curobjnode; curobjnode = curobjnode->next)
             {
               curobj = (DenemoObject *) curobjnode->data;
-              if (curobj->midi_events)
-                g_list_free (curobj->midi_events);      //data belongs to libsmf
-              curobj->midi_events = NULL;
               curobj->earliest_time = ticks_read * 60.0 / (cur_tempo * MIDI_RESOLUTION);        //smf_get_length_seconds(smf);
 
 
@@ -1250,7 +1302,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                               if (!(midi_override & DENEMO_OVERRIDE_HIDDEN))
                                 if (buf)
                                   {
-                                    if (NULL == put_event (buf, numbytes, &curobj->midi_events, track))
+                                    if (NULL == put_event (buf, numbytes, track))
                                       g_warning ("Invalid midi bytes in chord directive");
                                   }
                               break;
@@ -1338,7 +1390,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                       //g_debug("Adding Dummy event for rest %d %d %d\n", duration, ticks_read, ticks_written); 
                       event = midi_meta_text (1 /* comment */ , "rest");
                       smf_track_add_event_delta_pulses (track, event, duration);
-                      curobj->midi_events = g_list_append (curobj->midi_events, event);
+                      
                       ticks_written += duration;
                       event->user_pointer = curobj;
                       //g_debug("rest of %f seconds at %f\n", duration/(double)MIDI_RESOLUTION, curobj->latest_time);
@@ -1386,7 +1438,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                             {
                               if (chordval.has_dynamic)
                                 {
-                                  g_debug ("\nThis chord has a dynamic marking attatched\n");
+                                  //g_debug ("\nThis chord has a dynamic marking attatched\n");
                                   GList *dynamic = g_list_first (chordval.dynamics);
                                   cur_volume = string_to_vol (((GString *) dynamic->data)->str, cur_volume);
                                 }
@@ -1442,11 +1494,11 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                               event = smf_event_new_from_bytes (MIDI_NOTE_ON | midi_channel, n,(curstaffstruct->mute)? 0: (override_volume ? 127 : (gint) (master_volume * cur_volume /*FIXME as above, mix */ )));
                               smf_track_add_event_delta_pulses (track, event, mididelta);
                               event->user_pointer = curobj;
-                              curobj->midi_events = g_list_append (curobj->midi_events, event);
+                              
                               curobj->earliest_time = event->time_seconds;
                               curobj->latest_time = curobj->earliest_time + duration * 60.0 / (cur_tempo * MIDI_RESOLUTION);
 
-                              g_debug ("'%d len %d'", event->event_number, event->midi_buffer_length);
+                              //g_debug ("'%d len %d'", event->event_number, event->midi_buffer_length);
                               //printf ("volume = %i\n", (override_volume ? 0:mix));
                             }
                           else if (slur_kill_p (note_status, n))
@@ -1456,8 +1508,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                               smf_track_add_event_delta_pulses (track, event, mididelta);
                               //g_debug("Note  off for track %x at delta (%d) %.1f for cur_tempo %d\n", track, mididelta, event->time_seconds, cur_tempo);
                               event->user_pointer = curobj;
-                              curobj->midi_events = g_list_append (curobj->midi_events, event);
-
+                              
                               curobj->latest_time = event->time_seconds;
                               curobj->earliest_time = curobj->latest_time - duration * 60.0 / (cur_tempo * MIDI_RESOLUTION);
                               //g_debug("event off lur kill %f\n", event->time_seconds);
@@ -1506,7 +1557,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                               //g_debug("Note  off for track %x at delta (%d) %.1f for cur_tempo %d\n", track, mididelta, event->time_seconds, cur_tempo);
                               //g_debug("smf length after %d %f mididelta %d", smf_get_length_pulses(smf), smf_get_length_seconds(smf),mididelta);
                               event->user_pointer = curobj;
-                              curobj->midi_events = g_list_append (curobj->midi_events, event);
+                              
                               curobj->latest_time = event->time_seconds;
                               curobj->earliest_time = curobj->latest_time - duration * 60.0 / (cur_tempo * MIDI_RESOLUTION);
                               //g_debug("event off %f mididelta %d duration %d for curobj->type = %d\n", event->time_seconds, mididelta, duration, curobj->type);
@@ -1551,7 +1602,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                   event = midi_timesig (timesigupper, timesiglower);
                   smf_track_add_event_delta_pulses (track, event, 0);
                   event->user_pointer = curobj;
-                  curobj->midi_events = g_list_append (curobj->midi_events, event);
+                  
                   curobj->earliest_time = curobj->latest_time = event->time_seconds;    //= smf_get_length_seconds(smf);
                   break;
 
@@ -1624,7 +1675,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                   event = midi_keysig ((((keysig *) curobj->object)->number), curstaffstruct->keysig.isminor);
                   smf_track_add_event_delta_pulses (track, event, 0);
                   event->user_pointer = curobj;
-                  curobj->midi_events = g_list_append (curobj->midi_events, event);
+                  
                   curobj->earliest_time = curobj->latest_time = event->time_seconds;    //= smf_get_length_seconds(smf);
                   break;
 
@@ -1674,13 +1725,13 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
                             break;
                           case DENEMO_OVERRIDE_DURATION:
                             theduration = midi_interpretation;
-                            g_debug ("Duration is %d", theduration);
+                            //g_debug ("Duration is %d", theduration);
                             break;
                           default:
                             if (!(midi_override & DENEMO_OVERRIDE_HIDDEN))
                               if (buf)
                                 {g_print ("putting numbytes %d", numbytes);
-                                  if (NULL == put_event (buf, numbytes, &curobj->midi_events, track))
+                                  if (NULL == put_event (buf, numbytes, track))
                                     g_warning ("Directive has invalid MIDI bytes");
                                 }
                             break;
@@ -1766,49 +1817,19 @@ exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
   /********
    * Done!
    ********/
-  if (thefilename)
-    {
-      if (Denemo.project->movement->recorded_midi_track)
-        smf_add_track (smf, Denemo.project->movement->recorded_midi_track);
-      if(smf_save (smf, (const char *) thefilename))
-        g_debug("smf_save failed");
-      if (Denemo.project->movement->recorded_midi_track)
-        smf_track_remove_from_smf (Denemo.project->movement->recorded_midi_track);
-    }
-  /* we are done */
-  {
-    gboolean midi_track = FALSE;
+   save_smf_to_file (smf, thefilename);
+
+  
+  load_smf (si, smf);
 
 
-    g_static_mutex_lock (&smfmutex);
-    if (Denemo.project->movement->recorded_midi_track)
-      {
-        if (si->smf && (((smf_track_t *) Denemo.project->movement->recorded_midi_track)->smf == si->smf))
-          {
-            smf_track_remove_from_smf (Denemo.project->movement->recorded_midi_track);
-            midi_track = TRUE;
-          }
-      }
-    free_midi_data (si);
-    si->smf = smf;
-    if (midi_track)
-      smf_add_track (smf, Denemo.project->movement->recorded_midi_track);
 
+  if (si->start_time < 0.0)
+    si->start_time = 0.0;
+  if (si->end_time < 0.0)
+    si->end_time = smf_get_length_seconds (smf);
+  g_debug ("Start time %f end time %f\n", si->start_time, si->end_time);
 
-    si->smfsync = si->changecount;
-    g_static_mutex_unlock (&smfmutex);
-  }
-
-  if (start || end)
-    return exportmidi (NULL, si, 0, 0); // recurse if we have not generated all the MIDI for si
-  else
-    {
-      if (si->start_time < 0.0)
-        si->start_time = 0.0;
-      if (si->end_time < 0.0)
-        si->end_time = smf_get_length_seconds (smf);
-      g_debug ("Start time %f end time %f\n", si->start_time, si->end_time);
-    }
   call_out_to_guile ("(FinalizeMidiGeneration)");
   return smf_get_length_seconds (smf);
 }
