@@ -23,6 +23,7 @@
 #define ToggleLilyText_STRING  "ToggleLilyText"
 #define ToggleScript_STRING  "ToggleScript"
 #define TogglePrintView_STRING  "TogglePrintView"
+#define TogglePlaybackView_STRING  "TogglePlaybackView"
 #define ToggleScoreLayout_STRING  "ToggleScoreLayout"
 #define ToggleCommandManager_STRING  "ToggleCommandManager"
 #define ToggleLyricsView_STRING  "ToggleLyricsView"
@@ -63,6 +64,12 @@ SCM scheme_put_clip_obj (SCM tag, SCM value);
 SCM scheme_clear_clipboard (SCM);
 SCM scheme_get_staffs_in_clipboard (SCM);
 SCM scheme_get_measures_in_staff (SCM);
+SCM scheme_set_lines_in_staff (SCM);
+SCM scheme_set_staff_range_lo (SCM);
+SCM scheme_set_staff_range_hi (SCM);
+SCM scheme_set_staff_range (void);
+SCM scheme_shorten_staff_height (SCM);
+SCM scheme_set_color_of_staff (SCM);
 SCM scheme_get_staffs_in_movement (SCM);
 SCM scheme_staff_to_voice (SCM);
 SCM scheme_voice_to_staff (SCM);
@@ -107,7 +114,6 @@ SCM scheme_get_note_at_cursor (void);
 SCM scheme_get_dots (void);
 SCM scheme_get_note_base_duration (void);
 SCM scheme_get_note_duration (void);
-SCM scheme_get_onset_time (void);
 SCM scheme_get_recorded_midi_tempo (SCM index);
 SCM scheme_get_imported_midi_track (SCM index);
 SCM scheme_delete_imported_midi (void);
@@ -190,11 +196,14 @@ SCM scheme_get_user_input_with_snippets (SCM label, SCM prompt, SCM init, SCM mo
 SCM scheme_select_font (SCM);
 SCM scheme_select_color (SCM);
 SCM scheme_warningdialog (SCM);
+SCM scheme_info_with_hook (SCM message, SCM script);
 SCM scheme_infodialog (SCM message, SCM noblock);
 SCM scheme_progressbar (SCM);
 SCM scheme_progressbar_stop (void);
 SCM scheme_typeset_for_script (SCM);
 SCM scheme_print_typeset_pdf (void);
+SCM scheme_display_typeset_svg (SCM scaling, SCM part);
+SCM scheme_continous_typsetting (void);
 SCM scheme_get_char (void);
 SCM scheme_get_keypress (void);
 SCM scheme_get_command_keypress (void);
@@ -204,6 +213,7 @@ SCM scheme_lock_directive (SCM);
 SCM scheme_set_action_script_for_tag (SCM tag, SCM script);
 SCM scheme_put_standalone_directive (SCM tag, SCM width);
 SCM scheme_directive_change_tag (SCM tag);
+SCM scheme_choose_tag_at_cursor (void);
 SCM scheme_text_edit_standalone_directive (SCM);
 SCM scheme_delete_object_directive (SCM);
 SCM scheme_put_text_clipboard (SCM);
@@ -241,8 +251,10 @@ SCM scheme_bass_figure (SCM bass, SCM harmony);
 SCM scheme_spell_check_midi_chord (SCM);
 SCM scheme_get_cursor_note_as_midi (SCM);
 SCM scheme_get_note_as_midi (void);
+SCM scheme_refresh_cache (void);
 SCM scheme_refresh_display (SCM);
 SCM scheme_set_saved (SCM);
+SCM scheme_changecount (SCM);
 SCM scheme_get_saved (SCM);
 SCM scheme_mark_status (SCM);
 SCM scheme_get_help (SCM);
@@ -322,6 +334,7 @@ SCM scheme_get_checksum (SCM);
 SCM scheme_set_newbie (SCM);
 SCM scheme_synchronize_lyric_cursor (void);
 SCM scheme_insert_text_in_verse (SCM);
+SCM scheme_typeset_lyrics_for_staff (SCM);
 SCM scheme_get_verse (SCM);
 SCM scheme_put_verse (SCM);
 SCM scheme_append_to_verse (SCM);
