@@ -134,7 +134,7 @@ clef_change (DenemoProject * gui, actiontype action)
   int i;
 
   dialog = gtk_dialog_new_with_buttons (((action == CHANGEINITIAL) ? _("Set Clef") : _("Insert clef change")), NULL,    /* parent window */
-                                        (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_STOCK_CANCEL, NULL);
+                                        (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), _("_OK"), GTK_RESPONSE_ACCEPT, _("_Cancel"), GTK_RESPONSE_REJECT, NULL);
 
 
   GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
@@ -182,7 +182,7 @@ clef_change (DenemoProject * gui, actiontype action)
             DenemoObject *newclef = clef_new (clef);
           object_insert (gui, newclef);
          if(curstaffstruct->voicecontrol & DENEMO_SECONDARY)
-            newclef->isinvisible = choose_option (_("Choose Clef Visibility"), _("Affects display only"), _("Clef should be typeset"));
+            newclef->isinvisible = !choose_option (_("Choose Clef Visibility"), _("Affects display only"), _("Clef should be typeset"));
         }
       score_status (gui, TRUE);
       displayhelper (gui);
