@@ -8,6 +8,7 @@
 #include <string.h>
 #include <denemo/denemo.h>
 #include "core/utils.h"
+#include "core/view.h"
 #include "command/commandfuncs.h"
 #include "ui/dialogs.h"
 
@@ -127,7 +128,7 @@ score_properties_dialog (GtkAction * action, DenemoScriptParam * param)
   DenemoMovement *si = gui->movement;
   //g_assert (si != NULL);
 
-  dialog = gtk_dialog_new_with_buttons (_("Score properties"), GTK_WINDOW (Denemo.window), (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+  dialog = gtk_dialog_new_with_buttons (_("Score properties"), GTK_WINDOW (Denemo.window), (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), _("_OK"), GTK_RESPONSE_ACCEPT, _("_Cancel"), GTK_RESPONSE_REJECT, NULL);
 
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
   //gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
@@ -161,7 +162,7 @@ score_properties_dialog (GtkAction * action, DenemoScriptParam * param)
 
   papersetupcb *setup = (papersetupcb *) g_malloc0 (sizeof (papersetupcb));
   vbox = gtk_vbox_new (FALSE, 1);
-  label = gtk_label_new_with_mnemonic (_("Paper Size"));
+  label = gtk_label_new_with_mnemonic (_("Typesetter"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 
 #if GTK_MAJOR_VERSION==3
