@@ -14,6 +14,7 @@
 #include <denemo/denemo.h>
 #include "command/processstaffname.h"
 #include "command/staff.h"
+#include "core/view.h"
 #include "core/utils.h"
 #include "ui/dialogs.h"
 #include <stdlib.h>
@@ -26,6 +27,136 @@
 extern int ParseSoundfont (gchar * soundfont, gint index, gchar ** name, gint * preset, gint * bank);        //in "external" code libsffile/sfile.c
 
 
+static gchar *GM_Instrument_Names[] = {
+"Acoustic Grand Piano",
+"Bright Acoustic Piano",
+"Electric Grand Piano",
+"Honky-tonk Piano",
+"Electric Piano 1",
+"Electric Piano 2",
+"Harpsichord",
+"Clavinet",
+"Celesta",
+"Glockenspiel",
+"Music Box",
+"Vibraphone",
+"Marimba",
+"Xylophone",
+"Tubular Bells",
+"Dulcimer",
+"Drawbar Organ",
+"Percussive Organ",
+"Rock Organ",
+"Church Organ",
+"Reed Organ",
+"Accordion",
+"Harmonica",
+"Tango Accordion",
+"Acoustic Guitar (nylon)",
+"Acoustic Guitar (steel)",
+"Electric Guitar (jazz)",
+"Electric Guitar (clean)",
+"Electric Guitar (muted)",
+"Overdriven Guitar",
+"Distortion Guitar",
+"Guitar Harmonics",
+"Acoustic Bass",
+"Electric Bass (finger)",
+"Electric Bass (pick)",
+"Fretless Bass",
+"Slap Bass 1",
+"Slap Bass 2",
+"Synth Bass 1",
+"Synth Bass 2",
+"Violin",
+"Viola",
+"Cello",
+"Contrabass",
+"Tremolo Strings",
+"Pizzicato Strings",
+"Orchestral Harp",
+"Timpani",
+"String Ensemble 1",
+"String Ensemble 2",
+"Synth Strings 1",
+"Synth Strings 2",
+"Choir Aahs",
+"Voice Oohs",
+"Synth Choir",
+"Orchestra Hit",
+"Trumpet",
+"Trombone",
+"Tuba",
+"Muted Trumpet",
+"French Horn",
+"Brass Section",
+"Synth Brass 1",
+"Synth Brass 2",
+"Soprano Sax",
+"Alto Sax",
+"Tenor Sax",
+"Baritone Sax",
+"Oboe",
+"English Horn",
+"Bassoon",
+"Clarinet",
+"Piccolo",
+"Flute",
+"Recorder",
+"Pan Flute",
+"Blown bottle",
+"Shakuhachi",
+"Whistle",
+"Ocarina",
+"Lead 1 (square)",
+"Lead 2 (sawtooth)",
+"Lead 3 (calliope)",
+"Lead 4 chiff",
+"Lead 5 (charang)",
+"Lead 6 (voice)",
+"Lead 7 (fifths)",
+"Lead 8 (bass + lead)",
+"Pad 1 (new age)",
+"Pad 2 (warm)",
+"Pad 3 (polysynth)",
+"Pad 4 (choir)",
+"Pad 5 (bowed)",
+"Pad 6 (metallic)",
+"Pad 7 (halo)",
+"Pad 8 (sweep)",
+"FX 1 (rain)",
+"FX 2 (soundtrack)",
+"FX 3 (crystal)",
+"FX 4 (atmosphere)",
+"FX 5 (brightness)",
+"FX 6 (goblins)",
+"FX 7 (echoes)",
+"FX 8 (sci-fi)",
+"Sitar",
+"Banjo",
+"Shamisen",
+"Koto",
+"Kalimba",
+"Bagpipe",
+"Fiddle",
+"Shanai",
+"Tinkle Bell",
+"Agogo",
+"Steel Drums",
+"Woodblock",
+"Taiko Drum",
+"Melodic Tom",
+"Synth Drum",
+"Reverse Cymbal",
+"Guitar Fret Noise",
+"Breath Noise",
+"Seashore",
+"Bird Tweet",
+"Telephone Ring",
+"Helicopter",
+"Applause",
+"Gunshot"
+};
 
 
 /**
@@ -37,6 +168,7 @@ struct callbackdata
   DenemoProject *gui;
   DenemoStaff *staffstruct;
   GtkWidget *denemo_name;
+  GtkWidget *subpart;
   GtkWidget *midi_instrument;
   GtkWidget *midi_prognum;
   GtkWidget *midi_channel;
@@ -56,7 +188,7 @@ struct callbackdata
  * @param cbdata pointer to the callback data structure containing the preference data to set.
  * @return none
  */
-void
+static void
 set_properties (struct callbackdata *cbdata)
 {
 
@@ -91,6 +223,12 @@ set_properties (struct callbackdata *cbdata)
 
   /* rename of set staff/voice name */
   canonicalize_denemo_name ((gchar *) gtk_entry_get_text (GTK_ENTRY (cbdata->denemo_name)), staffstruct->denemo_name);
+  if(cbdata->subpart)
+    {
+     if(staffstruct->subpart==NULL)
+        staffstruct->subpart = g_string_new ("");
+     canonicalize_denemo_name ((gchar *) gtk_entry_get_text (GTK_ENTRY (cbdata->subpart)), staffstruct->subpart);
+    }
   set_lily_name (staffstruct->denemo_name, staffstruct->lily_name);
 
 
@@ -104,6 +242,7 @@ set_properties (struct callbackdata *cbdata)
 
   /* set MIDI channel/prognum */
   ASSIGNTEXT (midi_instrument);
+ 
   ASSIGNTEXT (device_port);
   ASSIGNBOOLEAN (override_volume);
   ASSIGNNUMBER (volume);
@@ -123,7 +262,10 @@ set_properties (struct callbackdata *cbdata)
               if (!strcmp (name, staffstruct->midi_instrument->str))
                 {
                   staffstruct->midi_prognum = preset;
-                  printf ("\nMIDI Instrument == %s \nMIDI PROGRAM == %d\n", staffstruct->midi_instrument->str, staffstruct->midi_prognum);
+                  gchar *scheme = g_strdup_printf ("(d-MidiInstrumentName \"%s\")", GM_Instrument_Names[preset&0xFF]);
+                  call_out_to_guile (scheme);
+                  g_free (scheme);
+                  printf ("\nMIDI Instrument == %s (GM name %s)\nMIDI PROGRAM == %d\n", staffstruct->midi_instrument->str,  GM_Instrument_Names[preset&0xFF], staffstruct->midi_prognum);
                   break;
                 }
             }
@@ -147,7 +289,7 @@ set_properties (struct callbackdata *cbdata)
       buffer[1] = staffstruct->midi_prognum;
       play_midi_event (DEFAULT_BACKEND, staffstruct->midi_port, buffer);
     }
-  g_debug ("Staff Transposition %d\n", staffstruct->transposition);
+  //g_debug ("Staff Transposition %d\n", staffstruct->transposition);
   score_status (cbdata->gui, TRUE);
 }
 
@@ -159,11 +301,11 @@ set_properties (struct callbackdata *cbdata)
 static gboolean
 staff_properties_change (void)
 {
-  DenemoMovement *si;
-  DenemoProject *gui;
-
+  DenemoProject *gui = Denemo.project;
+  DenemoMovement *si = gui->movement;
+  DenemoStaff *staffstruct = (DenemoStaff *) si->currentstaff->data;
   gboolean result = FALSE;
-  DenemoStaff *staffstruct;
+  
   GtkWidget *dialog;
   GtkWidget *notebook;
   GtkWidget *label;
@@ -171,53 +313,42 @@ staff_properties_change (void)
   GtkWidget *hbox;
   GtkWidget *entrywidget;
   static GString *entrycontent;
-  GList *instrument_list = NULL;
+  static GList *instrument_list = NULL;
   static struct callbackdata cbdata;
   gint i;
-
-  if (!instrument_list)
+  if (instrument_list)
     {
-      gint i;
-      gchar *name;
-      gint preset = 0, bank = 0;
-      gint npresets = ParseSoundfont (Denemo.prefs.fluidsynth_soundfont->str, 0, NULL, NULL, NULL);
-      if (npresets)
-        {
-          gchar **array = g_malloc0 (128 * sizeof (gchar *));
-          for (i = 0; i < npresets - 1; i++)
-            {
-              (void) ParseSoundfont (NULL, i, &name, &preset, &bank);
-              if (bank == 0) {
-                   array[preset&0x7F] = g_strdup ((gchar *) name);
-              }
-            }
-          for (i = 0; i < 128; i++)
-            if(array[i])
-                instrument_list = g_list_append(instrument_list, array[i]); 
-          g_free (array);
-        }
+            g_list_free_full (instrument_list, g_free);
+            instrument_list = NULL;
     }
-
-
-
   {
-    gui = Denemo.project;
-    si = gui->movement;
-    staffstruct = (DenemoStaff *) si->currentstaff->data;
-    /*  if(staffstruct->staff_prolog && staffstruct->staff_prolog->len) { */
-/*  warningdialog(_("This staff has a custom prolog for the staff.\n" */
-/*            "You will need to make your edits in the LilyPond window\n" */
-/*            "to see them in the print-out.")); */
-/*       } */
+  gint i;
+  gchar *name;
+  gint preset = 0, bank = 0;
+  gint npresets = ParseSoundfont (Denemo.prefs.fluidsynth_soundfont->str, 0, NULL, NULL, NULL);
+  if (npresets)
+    {
+      gchar **array = g_malloc0 (128 * sizeof (gchar *));
+      for (i = 0; i < npresets - 1; i++)
+        {
+          (void) ParseSoundfont (NULL, i, &name, &preset, &bank);
+          if (bank == 0) {
+               array[preset&0x7F] = g_strdup ((gchar *) name);
+          }
+        }
+      for (i = 0; i < 128; i++)
+        if(array[i])
+            instrument_list = g_list_append(instrument_list, array[i]); 
+      g_free (array);
+    }
   }
 
-
   if (!entrycontent)
     {
       entrycontent = g_string_new (NULL);
     }
 
-  dialog = gtk_dialog_new_with_buttons (_("Staff Properties"), GTK_WINDOW (Denemo.window), (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_STOCK_CANCEL, NULL);
+  dialog = gtk_dialog_new_with_buttons (_("Staff Properties"), GTK_WINDOW (Denemo.window), (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), _("_OK"), GTK_RESPONSE_ACCEPT, _("_Cancel"), GTK_RESPONSE_REJECT, NULL);
   //gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
   notebook = gtk_notebook_new ();
   GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
@@ -310,13 +441,15 @@ staff_properties_change (void)
   NEWPAGE (_("Typeset Appearance"));
   TEXTENTRY (_("Part name:"), denemo_name);
   gtk_widget_set_tooltip_text (hbox, _( "All staffs with the same part name will be typeset with the Print Part command. Use a blank part name for staffs that should be printed with every part."));
-  INTENTRY_LIMITS (_("Number of Staff Lines:"), no_of_lines, 1, 5);
-
+  TEXTENTRY (_("Sub Part name:"), subpart);
+  gtk_widget_set_tooltip_text (hbox, _( "If a single part (e.g. piano) has more than one staff they should be named here."));
+  
   /* Display appearance tab */
   NEWPAGE ("Display Appearance");
   //gtk_widget_grab_focus (entrywidget);
   INTENTRY_LIMITS (_("Space above:"), space_above, 0, MAXEXTRASPACE);
   INTENTRY_LIMITS (_("Space below:"), space_below, 0, MAXEXTRASPACE);
+  INTENTRY_LIMITS (_("Number of Display Staff Lines:"), no_of_lines, 1, 5);
 
 
   /* MIDI tab */
@@ -383,7 +516,9 @@ staff_properties_change_cb (GtkAction * action, DenemoScriptParam * param)
       if (*query)
         if (!strcmp ("denemo_name", query))
           {
-            g_string_assign (param->string, staff->denemo_name->str);
+            g_string_assign (param->string, staff->denemo_name->str);  
+            if (staff->subpart)
+                g_string_append_printf (param->string, "_%s", staff->subpart->str);
             param->status = TRUE;
           }
       if (*query)
@@ -416,13 +551,20 @@ staff_properties_change_cb (GtkAction * action, DenemoScriptParam * param)
   take_snapshot ();
   signal_structural_change (Denemo.project);
   if (denemo_name)
-    {
-      g_string_assign (staff->denemo_name, denemo_name);
-      canonicalize_denemo_name (denemo_name, staff->denemo_name);
+    { gboolean ok = TRUE;
+      gchar *name = strtok (denemo_name, "_");
+      gchar *subpart = strtok (NULL, "_");
+      if (name)
+        ok = canonicalize_denemo_name (name, staff->denemo_name);
+      else
+        g_string_assign (staff->denemo_name, "");
+      if (ok && subpart)
+        ok = canonicalize_denemo_name (subpart, staff->subpart);
       set_lily_name (staff->denemo_name, staff->lily_name);
-      param->status = TRUE;
+      param->status = ok;
       return;
     }
+ 
   if (device_port)
     {
       g_string_assign (staff->device_port, device_port);
